#!/usr/bin/env python3

weeDict = {
	'V': 'vblex', # ipf:impf, pf:perf, tran:tv, intr:iv
	'ADV': 'adv',
	'A': 'adj',
	'S': 'n', # f, m, n, inan:nn
	#'S': 'np.al',
	#'S.persn': 'np.ant', # f, m
	'A-PRO': ['det', 'prn', 'det.all', 'det.dem', 'prn.dem', 'det.pos',
		'prn.pos'],
	'S-PRO': ['prn', 'prn.all', 'prn.def', 'prn.dem', 'prn.ind', 'prn.itg',
		'prn.neg', 'prn.pers', 'prn.ref', 'prn.rel'],
	'PR': 'pr',
	'CONJ': ['cnjadv', 'cnjcoo', 'cnjsub'],
	'INTJ': 'ij',
	'NUM': 'num',
	'ANUM': 'num.ord', 
	'A-NUM': 'num.ord', # typo in na_ostrove.xhtml, should be ANUM 
	'PART': 'part', # ☹
	'ADV-PRO': ['adv', 'adv.itg', 'adv.rel'],
	'PRAEDIC': 'pred',
	'PRAEDIC-PRO': 'prn.pred',
	'PARENTH': 'paren', # parenthetical
	'3p': 'p3',
	'2p': 'p2',
	'1p': 'p1',
	'sg': 'sg',
	'pl': 'pl',
	'nom': 'nom',
	'dat': 'dat',
	'dat2': 'dat',
	'gen': 'gen',
	'gen2': 'gen',
	'acc': 'acc',
	'acc2': 'acc',
	'loc': 'prp',
	'loc2': 'prp',
	'ins': 'ins',
	'inan': 'nn',
	'anim': 'aa',
	'intr': 'iv',
	'tran': 'tv',
	'm': 'm',
	'n': 'nt',
	'f': 'f',
	'patrn': 'pat',
	'famn': 'cog',
	'persn': 'ant',
	'imper': 'imp', # imperative
	'imper2': 'imp',
	'ipf': 'impf', # imperfective
	'pf': 'perf',
	'praes': 'pres',
	'praet': 'past',
	'fut': 'fut',
	'inf': 'inf',
	'ger': ['pprs.adv', 'pp.adv'],
	'partcp': 'pp',
	'brev': 'short',
	'pass': 'pasv',
	'comp': 'comp',

	# NUM=ciph : num

	# obsc - obscene
	# act - active
	# indic - indicative
	# med - reflexive - hmm
	# comp2 - special comparative?
	# anom - anomalous form?
	# ciph??
	# adnum: count?
	# m-f - masculine/feminine
	# zoon?
	# distort - like anom?
	# plen - full form adj?
	# NONLEX - non-[Russian ]word?
}

def rnc2cg(parse):
	# convert each RNC tag to a CG tag
	# exclude unconvertible tags
	global weeDict

	outParse = {}
	for key in parse.keys():
		outParse[key] = []
		for tag in parse[key]:
			if tag in weeDict:
				if "." in weeDict[tag]:
					splitTags = weeDict[tag].split(".")
					for splitTag in splitTags:
						outParse[key].append(splitTag)
				else:
					outParse[key].append(weeDict[tag])
	
	#print(outParse)
	
	return outParse

bigDict = {
	"A.0.f.sg.nom.plen": "",
	"A.0.m.sg.nom.plen": "",
	"A.0.pl.nom.plen": "",
	"A.0.sg.acc.inan.plen": "",
	"A.0.sg.gen.plen": "",
	"A.0.sg.nom": "",
	"A.0.sg.nom.plen": "",
	"A.brev": "",
	"A.brev.f.sg": "",
	"A.brev.f.sg.acc": "",
	"A.brev.m.sg": "",
	"A.brev.n.sg": "",
	"A.brev.pl": "",
	"A.brev.sg": "",
	"A.brev.sg.f": "",
	"A.brev.sg.f.distort": "",
	"A.brev.sg.m": "",
	"A.brev.sg.n": "",
	"A.comp": "",
	"A.comp2": "",
	"A.comp.anom": "",
	"ADV": "",
	"ADV.abbr": "",
	"ADV.anom": "",
	"ADV.comp": "",
	"ADV.comp2": "",
	"ADV.comp.anom": "",
	"ADV.distort": "",
	"ADV-PRO": "",
	"ADV-PRO.abbr": "",
	"ADV-PRO.anom": "",
	"ADV-PRO.comp": "",
	"ADV-PRO.comp2": "",
	"ADV-PRO.distort": "",
	"A.f.acc.brev": "",
	"A.f.brev.sg.acc": "",
	"A.f.sg.acc": "",
	"A.f.sg.acc.inan.plen": "",
	"A.f.sg.acc.inan.plen.abbr": "",
	"A.f.sg.acc.plen": "",
	"A.f.sg.acc.plen.ciph": "",
	"A.f.sg.brev": "",
	"A.f.sg.brev.acc.anom": "",
	"A.f.sg.brev.distort": "",
	"A.f.sg.dat.brev.anom": "",
	"A.f.sg.dat.plen": "",
	"A.f.sg.dat.plen.ciph": "",
	"A.f.sg.gen": "",
	"A.f.sg.gen.plen": "",
	"A.f.sg.gen.plen.abbr": "",
	"A.f.sg.gen.plen.ciph": "",
	"A.f.sg.gen.plen.ciph.abbr": "",
	"A.f.sg.ins.plen": "",
	"A.f.sg.ins.plen.ciph": "",
	"A.f.sg.loc": "",
	"A.f.sg.loc.plen": "",
	"A.f.sg.loc.plen.ciph": "",
	"A.f.sg.nom": "",
	"A.f.sg.nom.plen": "",
	"A.f.sg.nom.plen.abbr": "",
	"A.f.sg.nom.plen.ciph": "",
	"A.f.sg.nom.plen.distort": "",
	"A.gen.pl.plen": "",
	"A.ins.sg.m.plen": "",
	"A.m.pl.acc.inan.plen": "",
	"A.m.pl.gen.plen": "",
	"A.m.pl.nom.plen": "",
	"A.m.sg.acc.anim.plen": "",
	"A.m.sg.acc.anim.plen.abbr": "",
	"A.m.sg.acc.anim.plen.ciph": "",
	"A.m.sg.acc.inan": "",
	"A.m.sg.acc.inan.plen": "",
	"A.m.sg.acc.inan.plen.ciph": "",
	"A.m.sg.acc.inan.plen.distort": "",
	"A.m.sg.acc.plen": "",
	"A.m.sg.acc.plen.abbr": "",
	"A.m.sg.brev": "",
	"A.m.sg.brev.anom": "",
	"A.m.sg.dat.abbr": "",
	"A.m.sg.dat.plen": "",
	"A.m.sg.dat.plen.ciph": "",
	"A.m.sg.gen": "",
	"A.m.sg.gen.distort": "",
	"A.m.sg.gen.plen": "",
	"A.m.sg.gen.plen.abbr": "",
	"A.m.sg.gen.plen.ciph": "",
	"A.m.sg.ins": "",
	"A.m.sg.ins.plen": "",
	"A.m.sg.ins.plen.ciph": "",
	"A.m.sg.loc.plen": "",
	"A.m.sg.loc.plen.abbr": "",
	"A.m.sg.loc.plen.anom": "",
	"A.m.sg.loc.plen.ciph": "",
	"A.m.sg.nom.ciph": "",
	"A.m.sg.nom.plen": "",
	"A.m.sg.nom.plen.abbr": "",
	"A.m.sg.nom.plen.anom": "",
	"A.m.sg.nom.plen.ciph": "",
	"A.m.sg.nom.plen.distort": "",
	"A.n.brev": "",
	"A.n.nom.brev": "",
	"A.n.pl.acc.inan.plen": "",
	"A.n.sg.acc.inan.plen": "",
	"A.n.sg.acc.inan.plen.ciph": "",
	"A.n.sg.acc.plen": "",
	"A.n.sg.brev": "",
	"A.n.sg.dat.abbr": "",
	"A.n.sg.dat.plen": "",
	"A.n.sg.dat.plen.anom": "",
	"A.n.sg.gen": "",
	"A.n.sg.gen.abbr": "",
	"A.n.sg.gen.plen": "",
	"A.n.sg.gen.plen.abbr": "",
	"A.n.sg.ins.plen": "",
	"A.n.sg.loc.abbr": "",
	"A.n.sg.loc.plen": "",
	"A.n.sg.loc.plen.anom": "",
	"A.n.sg.loc.plen.ciph": "",
	"A.n.sg.nom.abbr": "",
	"A.n.sg.nom.plen": "",
	"A.n.sg.nom.plen.abbr": "",
	"A.n.sg.nom.plen.ciph": "",
	"A.n.sg.nom.plen.distort": "",
	"ANUM.ciph": "",
	"ANUM.f.acc": "",
	"ANUM.f.dat": "",
	"ANUM.f.gen": "",
	"ANUM.f.ins": "",
	"ANUM.f.loc": "",
	"ANUM.f.nom": "",
	"ANUM.f.sg.acc": "",
	"ANUM.f.sg.acc.ciph": "",
	"ANUM.f.sg.dat": "",
	"ANUM.f.sg.dat.ciph": "",
	"ANUM.f.sg.gen": "",
	"ANUM.f.sg.gen.ciph": "",
	"ANUM.f.sg.ins": "",
	"ANUM.f.sg.ins.ciph": "",
	"ANUM.f.sg.loc": "",
	"ANUM.f.sg.loc.ciph": "",
	"A-NUM.f.sg.nom": "",
	"ANUM.f.sg.nom": "",
	"ANUM.f.sg.nom.abbr": "",
	"ANUM.f.sg.nom.ciph": "",
	"ANUM.gen": "",
	"ANUM.m.acc": "",
	"ANUM.m.acc.anim": "",
	"ANUM.m.acc.inan": "",
	"ANUM.m.dat": "",
	"ANUM.m.gen": "",
	"ANUM.m.gen.sg.ciph": "",
	"ANUM.m.ins": "",
	"ANUM.m.loc": "",
	"ANUM.m.nom": "",
	"ANUM.m.sg.acc": "",
	"ANUM.m.sg.acc.anim": "",
	"ANUM.m.sg.acc.ciph": "",
	"ANUM.m.sg.acc.inan": "",
	"ANUM.m.sg.acc.inan.ciph": "",
	"ANUM.m.sg.dat": "",
	"ANUM.m.sg.dat.ciph": "",
	"ANUM.m.sg.gen": "",
	"ANUM.m.sg.gen.ciph": "",
	"ANUM.m.sg.ins": "",
	"ANUM.m.sg.ins.ciph": "",
	"ANUM.m.sg.loc": "",
	"ANUM.m.sg.loc.ciph": "",
	"ANUM.m.sg.loc.ciph.abbr": "",
	"ANUM.m.sg.nom": "",
	"ANUM.m.sg.nom.ciph": "",
	"ANUM.n.acc": "",
	"ANUM.n.acc.inan": "",
	"ANUM.n.dat": "",
	"ANUM.n.gen": "",
	"ANUM.n.ins": "",
	"ANUM.n.loc": "",
	"ANUM.n.nom": "",
	"ANUM.nom": "",
	"ANUM.n.sg.acc": "",
	"ANUM.n.sg.acc.ciph": "",
	"ANUM.n.sg.acc.inan": "",
	"ANUM.n.sg.acc.inan.ciph": "",
	"ANUM.n.sg.dat": "",
	"ANUM.n.sg.gen": "",
	"ANUM.n.sg.gen.ciph": "",
	"ANUM.n.sg.gen.ciph.abbr": "",
	"ANUM.n.sg.gen.distort": "",
	"ANUM.n.sg.ins": "",
	"ANUM.n.sg.ins.ciph": "",
	"ANUM.n.sg.loc": "",
	"ANUM.n.sg.loc.ciph": "",
	"ANUM.n.sg.nom": "",
	"ANUM.n.sg.nom.ciph": "",
	"ANUM.n.sg.nom.ciph.abbr": "",
	"ANUM.pl.acc": "",
	"ANUM.pl.acc.anim": "",
	"ANUM.pl.acc.ciph": "",
	"ANUM.pl.acc.inan": "",
	"ANUM.pl.acc.inan.abbr": "",
	"ANUM.pl.acc.inan.ciph": "",
	"ANUM.pl.acc.inan.ciph.abbr": "",
	"ANUM.pl.dat": "",
	"ANUM.pl.dat.ciph": "",
	"ANUM.pl.gen": "",
	"ANUM.pl.gen.ciph": "",
	"ANUM.pl.gen.ciph.abbr": "",
	"ANUM.pl.ins": "",
	"ANUM.pl.ins.ciph": "",
	"ANUM.pl.ins.ciph.abbr": "",
	"ANUM.pl.loc": "",
	"ANUM.pl.loc.ciph": "",
	"ANUM.pl.nom": "",
	"ANUM.pl.nom.ciph": "",
	"ANUM.sg.acc.inan.ciph": "",
	"ANUM.sg.f.acc": "",
	"ANUM.sg.f.acc.ciph": "",
	"ANUM.sg.f.dat": "",
	"ANUM.sg.f.dat.ciph": "",
	"ANUM.sg.f.dat.ciph.abbr": "",
	"ANUM.sg.f.gen": "",
	"ANUM.sg.f.gen.ciph": "",
	"ANUM.sg.f.ins": "",
	"ANUM.sg.f.ins.ciph": "",
	"ANUM.sg.f.loc": "",
	"ANUM.sg.f.loc.ciph": "",
	"ANUM.sg.f.nom": "",
	"ANUM.sg.f.nom.ciph": "",
	"ANUM.sg.gen": "",
	"ANUM.sg.gen.ciph": "",
	"ANUM.sg.m.acc.anim": "",
	"ANUM.sg.m.acc.ciph": "",
	"ANUM.sg.m.acc.inan": "",
	"ANUM.sg.m.acc.inan.ciph": "",
	"ANUM.sg.m.dat": "",
	"ANUM.sg.m.gen": "",
	"ANUM.sg.m.gen.ciph": "",
	"ANUM.sg.m.ins": "",
	"ANUM.sg.m.loc": "",
	"ANUM.sg.m.loc.ciph": "",
	"ANUM.sg.m.nom": "",
	"ANUM.sg.n.acc.ciph": "",
	"ANUM.sg.n.acc.inan": "",
	"ANUM.sg.n.acc.inan.abbr": "",
	"ANUM.sg.n.dat": "",
	"ANUM.sg.n.gen": "",
	"ANUM.sg.n.gen.ciph": "",
	"ANUM.sg.n.gen.distort": "",
	"ANUM.sg.n.ins": "",
	"ANUM.sg.n.loc": "",
	"ANUM.sg.n.nom": "",
	"ANUM.sg.n.nom.ciph": "",
	"ANUM.sg.nom": "",
	"A.obsc.f.sg.ins.plen": "",
	"A.obsc.f.sg.nom.abbr": "",
	"A.obsc.pl.gen.plen": "",
	"A.pl.acc2.anim.plen": "",
	"A.pl.acc.anim.plen": "",
	"A.pl.acc.inan": "",
	"A.pl.acc.inan.plen": "",
	"A.pl.acc.inan.plen.abbr.ciph": "",
	"A.pl.acc.inan.plen.anom": "",
	"A.pl.acc.inan.plen.ciph": "",
	"A.pl.acc.inan.plen.ciph.abbr": "",
	"A.pl.acc.plen": "",
	"A.pl.acc.plen.distort": "",
	"A.pl.brev": "",
	"A.pl.brev.distort": "",
	"A.pl.dat.plen": "",
	"A.pl.dat.plen.abbr": "",
	"A.pl.dat.plen.ciph": "",
	"A.pl.dat.plen.ciph.abbr": "",
	"A.pl.dat.plen.distort": "",
	"A.plen": "",
	"A.pl.gen": "",
	"A.pl.gen.abbr": "",
	"A.pl.gen.distort": "",
	"A.pl.gen.plen": "",
	"A.pl.gen.plen.abbr": "",
	"A.pl.gen.plen.ciph": "",
	"A.pl.ins": "",
	"A.pl.ins.plen": "",
	"A.pl.ins.plen.abbr": "",
	"A.pl.ins.plen.ciph": "",
	"A.pl.loc.plen": "",
	"A.pl.loc.plen.anom": "",
	"A.pl.nom": "",
	"A.pl.nom.abbr": "",
	"A.pl.nom.distort": "",
	"A.pl.nom.plen": "",
	"A.pl.nom.plen.abbr": "",
	"A.pl.nom.plen.anom": "",
	"A.pl.nom.plen.ciph": "",
	"A.pl.nom.plen.distort": "",
	"A.pl.n.plen.ciph": "",
	"A-PRO": "",
	"A-PRO.brev.pl": "",
	"A-PRO.brev.sg.f": "",
	"A-PRO.brev.sg.m": "",
	"A-PRO.dat.pl": "",
	"A-PRO.f.sg.acc": "",
	"A-PRO.f.sg.acc.anom": "",
	"A-PRO.f.sg.acc.distort": "",
	"A-PRO.f.sg.acc.inan": "",
	"A-PRO.f.sg.acc.inan.anom": "",
	"A-PRO.f.sg.dat": "",
	"A-PRO.f.sg.dat.anom": "",
	"A-PRO.f.sg.gen": "",
	"A-PRO.f.sg.gen.abbr": "",
	"A-PRO.f.sg.ins": "",
	"A-PRO.f.sg.loc": "",
	"A-PRO.f.sg.nom": "",
	"A-PRO.f.sg.nom.abbr": "",
	"A-PRO.f.sg.nom.anom": "",
	"A-PRO.m.gen": "",
	"A-PRO.m.loc": "",
	"A-PRO.m.pl.gen.abbr": "",
	"A-PRO.m.sg": "",
	"A-PRO.m.sg.acc": "",
	"A-PRO.m.sg.acc.anim": "",
	"A-PRO.m.sg.acc.anom": "",
	"A-PRO.m.sg.acc.inan": "",
	"A-PRO.m.sg.dat": "",
	"A-PRO.m.sg.gen": "",
	"A-PRO.m.sg.gen.anom": "",
	"A-PRO.m.sg.ins": "",
	"A-PRO.m.sg.ins.abbr": "",
	"A-PRO.m.sg.loc": "",
	"A-PRO.m.sg.nom": "",
	"A-PRO.n.nom.abbr": "",
	"A-PRO.nom.f.sg": "",
	"A-PRO.nom.m.sg": "",
	"A-PRO.nom.n.sg": "",
	"A-PRO.nom.pl": "",
	"A-PRO.n.sg.acc": "",
	"A-PRO.n.sg.acc.inan": "",
	"A-PRO.n.sg.acc.inan.abbr": "",
	"A-PRO.n.sg.acc.inan.distort": "",
	"A-PRO.n.sg.dat": "",
	"A-PRO.n.sg.gen": "",
	"A-PRO.n.sg.ins": "",
	"A-PRO.n.sg.loc": "",
	"A-PRO.n.sg.loc.abbr": "",
	"A-PRO.n.sg.nom": "",
	"A-PRO.n.sg.nom.abbr": "",
	"A-PRO.n.sg.nom.distort": "",
	"A-PRO.pl.acc": "",
	"A-PRO.pl.acc.anim": "",
	"A-PRO.pl.acc.inan": "",
	"A-PRO.pl.acc.inan.abbr": "",
	"A-PRO.pl.dat": "",
	"A-PRO.pl.gen": "",
	"A-PRO.pl.gen.abbr": "",
	"A-PRO.pl.gen.anom": "",
	"A-PRO.pl.gen.plen": "",
	"A-PRO.pl.ins": "",
	"A-PRO.pl.ins.abbr": "",
	"A-PRO.pl.loc": "",
	"A-PRO.pl.loc.abbr": "",
	"A-PRO.pl.m.dat": "",
	"A-PRO.pl.nom": "",
	"A-PRO.pl.nom.abbr": "",
	"A-PRO.pl.nom.anom": "",
	"A-PRO.pl.nom.distort": "",
	"A-PRO.sg.f.acc": "",
	"A-PRO.sg.f.acc.inan": "",
	"A-PRO.sg.f.dat": "",
	"A-PRO.sg.f.gen": "",
	"A-PRO.sg.f.ins": "",
	"A-PRO.sg.f.loc": "",
	"A-PRO.sg.f.nom": "",
	"A-PRO.sg.gen.abbr": "",
	"A-PRO.sg.ins": "",
	"A-PRO.sg.m.3p.gen": "",
	"A-PRO.sg.m.acc": "",
	"A-PRO.sg.m.acc.anim": "",
	"A-PRO.sg.m.acc.inan": "",
	"A-PRO.sg.m.dat": "",
	"A-PRO.sg.m.gen": "",
	"A-PRO.sg.m.gen.abbr": "",
	"A-PRO.sg.m.gen.distort": "",
	"A-PRO.sg.m.ins": "",
	"A-PRO.sg.m.loc": "",
	"A-PRO.sg.m.nom": "",
	"A-PRO.sg.m.nom.distort": "",
	"A-PRO.sg.n.acc": "",
	"A-PRO.sg.n.acc.inan": "",
	"A-PRO.sg.n.dat": "",
	"A-PRO.sg.n.gen": "",
	"A-PRO.sg.n.gen.anom": "",
	"A-PRO.sg.n.ins": "",
	"A-PRO.sg.n.loc": "",
	"A-PRO.sg.n.nom": "",
	"A-PRO.sg.n.nom.abbr": "",
	"A-PRO.sg.n.nom.distort": "",
	"A.sg.brev.m": "",
	"A.sg.brev.n": "",
	"A.sg.f.acc.inan.plen": "",
	"A.sg.f.acc.plen": "",
	"A.sg.f.dat.plen": "",
	"A.sg.f.gen.plen": "",
	"A.sg.f.gen.plen.anom": "",
	"A.sg.f.gen.plen.distort": "",
	"A.sg.f.ins.plen": "",
	"A.sg.f.loc.plen": "",
	"A.sg.f.nom.distort": "",
	"A.sg.f.nom.plen": "",
	"A.sg.f.nom.plen.distort": "",
	"A.sg.gen": "",
	"A.sg.loc.f.plen": "",
	"A.sg.loc.plen": "",
	"A.sg.m.acc.anim.plen": "",
	"A.sg.m.acc.inan.plen": "",
	"A.sg.m.acc.inan.plen.abbr": "",
	"A.sg.m.brev": "",
	"A.sg.m.dat": "",
	"A.sg.m.dat.plen": "",
	"A.sg.m.gen.plen": "",
	"A.sg.m.gen.plen.abbr": "",
	"A.sg.m.ins.plen": "",
	"A.sg.m.loc.plen": "",
	"A.sg.m.loc.plen.abbr": "",
	"A.sg.m.nom.plen": "",
	"A.sg.m.nom.plen.abbr": "",
	"A.sg.m.nom.plen.distort": "",
	"A.sg.n.acc.inan.plen": "",
	"A.sg.n.brev": "",
	"A.sg.n.dat.plen": "",
	"A.sg.n.gen.plen": "",
	"A.sg.n.ins.plen": "",
	"A.sg.n.loc": "",
	"A.sg.n.loc.plen": "",
	"A.sg.n.nom.brev": "",
	"A.sg.n.nom.plen": "",
	"A.sg.n.nom.plen.abbr": "",
	"A.sg.nom.plen": "",
	"CONJ": "",
	"CONJ.distort": "",
	"INIT.abbr": "",
	"INTJ": "",
	"INTJ.distort": "",
	"INTJ.obsc": "",
	"NONLEX": "",
	"NONLEX.abbr": "",
	"NUM": "",
	"NUM.acc": "",
	"NUM.acc.anom": "",
	"NUM.acc.ciph": "",
	"NUM.acc.distort": "",
	"NUM.acc.f": "",
	"NUM.acc.m": "",
	"NUM.acc.n": "",
	"NUM.ciph": "",
	"NUM.comp": "",
	"NUM.comp2": "",
	"NUM.dat": "",
	"NUM.dat2": "",
	"NUM.dat.ciph": "",
	"NUM.dat.m": "",
	"NUM.distort": "",
	"NUM.f.acc": "",
	"NUM.f.dat": "",
	"NUM.f.gen": "",
	"NUM.f.ins": "",
	"NUM.f.loc": "",
	"NUM.f.nom": "",
	"NUM.gen": "",
	"NUM.gen.ciph": "",
	"NUM.gen.distort": "",
	"NUM.ins": "",
	"NUM.ins.ciph": "",
	"NUM.ins.f": "",
	"NUM.loc": "",
	"NUM.loc.ciph": "",
	"NUM.m.acc": "",
	"NUM.m.acc2": "",
	"NUM.m.dat": "",
	"NUM.m.gen": "",
	"NUM.m.ins": "",
	"NUM.m.loc": "",
	"NUM.m.nom": "",
	"NUM.n.acc": "",
	"NUM.n.dat": "",
	"NUM.n.gen": "",
	"NUM.n.ins": "",
	"NUM.n.loc": "",
	"NUM.n.nom": "",
	"NUM.nom": "",
	"NUM.nom.distort": "",
	"NUM.nom.f": "",
	"NUM.nom.m": "",
	"NUM.nom.n": "",
	"PARENTH": "",
	"PARENTH.abbr": "",
	"PARENTH.distort": "",
	"PART": "",
	"PART.anom": "",
	"PART.distort": "",
	"PR": "",
	"PR.abbr": "",
	"PRAEDIC": "",
	"PRAEDIC.comp": "",
	"PRAEDIC.comp2": "",
	"PRAEDIC.comp.anom": "",
	"PRAEDIC.distort": "",
	"PRAEDIC-PRO": "",
	"PRAEDIC-PRO.dat": "",
	"PRAEDIC-PRO.ins": "",
	"PRAEDIC-PRO.sg.acc": "",
	"PRAEDIC-PRO.sg.dat": "",
	"PRAEDIC-PRO.sg.gen": "",
	"PRAEDIC-PRO.sg.ins": "",
	"PR.anom": "",
	"PR.distort": "",
	"S.0.n.inan.pl.acc": "",
	"S.0.pl.acc": "",
	"S.0.pl.dat": "",
	"S.0.pl.gen": "",
	"S.0.pl.ins": "",
	"S.0.pl.loc": "",
	"S.0.pl.nom": "",
	"S.0.pl.nom.distort": "",
	"S.0.sg.acc": "",
	"S.0.sg.dat": "",
	"S.0.sg.gen": "",
	"S.0.sg.ins": "",
	"S.0.sg.loc": "",
	"S.0.sg.nom": "",
	"S.anim.m.sg.nom": "",
	"S.anim.pl.0.gen": "",
	"S.anim.sg.gen.n": "",
	"S.anim.sg.nom": "",
	"S.famn.anim.0.m.sg.nom": "",
	"S.famn.anim.sg.nom": "",
	"S.famn.f.anim.0.pl.gen": "",
	"S.famn.f.anim.0.pl.nom": "",
	"S.famn.f.anim.0.sg.acc": "",
	"S.famn.f.anim.0.sg.dat": "",
	"S.famn.f.anim.0.sg.gen": "",
	"S.famn.f.anim.0.sg.ins": "",
	"S.famn.f.anim.0.sg.loc": "",
	"S.famn.f.anim.0.sg.nom": "",
	"S.famn.f.anim.nom": "",
	"S.famn.f.anim.pl.acc": "",
	"S.famn.f.anim.sg.acc": "",
	"S.famn.f.anim.sg.dat": "",
	"S.famn.f.anim.sg.gen": "",
	"S.famn.f.anim.sg.ins": "",
	"S.famn.f.anim.sg.loc": "",
	"S.famn.f.anim.sg.nom": "",
	"S.famn.f.sg.acc": "",
	"S.famn.f.sg.dat": "",
	"S.famn.f.sg.gen": "",
	"S.famn.f.sg.nom": "",
	"S.famn.m.0.nom": "",
	"S.famn.m.anim.0.pl.gen": "",
	"S.famn.m.anim.0.pl.ins": "",
	"S.famn.m.anim.0.pl.nom": "",
	"S.famn.m.anim.0.sg.acc": "",
	"S.famn.m.anim.0.sg.dat": "",
	"S.famn.m.anim.0.sg.gen": "",
	"S.famn.m.anim.0.sg.ins": "",
	"S.famn.m.anim.0.sg.loc": "",
	"S.famn.m.anim.0.sg.nom": "",
	"S.famn.m.anim.nom.sg": "",
	"S.famn.m.anim.pl.acc": "",
	"S.famn.m.anim.pl.dat": "",
	"S.famn.m.anim.pl.gen": "",
	"S.famn.m.anim.pl.ins": "",
	"S.famn.m.anim.pl.loc": "",
	"S.famn.m.anim.pl.nom": "",
	"S.famn.m.anim.sg.acc": "",
	"S.famn.m.anim.sg.acc2": "",
	"S.famn.m.anim.sg.dat": "",
	"S.famn.m.anim.sg.gen": "",
	"S.famn.m.anim.sg.gen.anom": "",
	"S.famn.m.anim.sg.ins": "",
	"S.famn.m.anim.sg.loc": "",
	"S.famn.m.anim.sg.nom": "",
	"S.famn.m.anim.sg.nom.distort": "",
	"S.famn.m.anim.sg.voc": "",
	"S.famn.m-f.0.anim.sg.nom": "",
	"S.famn.m-f.0.sg.nom": "",
	"S.famn.m-f.anim.0.sg.acc": "",
	"S.famn.m-f.anim.0.sg.dat": "",
	"S.famn.m-f.anim.0.sg.gen": "",
	"S.famn.m-f.anim.0.sg.ins": "",
	"S.famn.m-f.anim.0.sg.loc": "",
	"S.famn.m-f.anim.0.sg.nom": "",
	"S.famn.m-f.anim.sg.dat": "",
	"S.famn.m-f.anim.sg.gen": "",
	"S.famn.m-f.anim.sg.ins": "",
	"S.famn.m-f.anim.sg.nom": "",
	"S.famn.m.sg.acc": "",
	"S.famn.m.sg.gen": "",
	"S.famn.m.sg.nom": "",
	"S.famn.n.anim.sg.acc": "",
	"S.famn.n.inan.0.sg.gen": "",
	"S.famn.n.inan.0.sg.ins": "",
	"S.famn.pl.anim.dat": "",
	"S.famn.pl.anim.gen": "",
	"S.famn.pl.anim.nom": "",
	"S.f.anim.0.pl.gen": "",
	"S.f.anim.0.pl.ins": "",
	"S.f.anim.0.pl.nom": "",
	"S.f.anim.0.sg.acc": "",
	"S.f.anim.0.sg.gen": "",
	"S.f.anim.0.sg.ins": "",
	"S.f.anim.0.sg.loc": "",
	"S.f.anim.0.sg.nom": "",
	"S.f.anim.anom": "",
	"S.f.anim.obsc.pl.nom": "",
	"S.f.anim.obsc.sg.nom": "",
	"S.f.anim.persn.sg.gen": "",
	"S.f.anim.pl.acc": "",
	"S.f.anim.pl.acc2": "",
	"S.f.anim.pl.dat": "",
	"S.f.anim.pl.gen": "",
	"S.f.anim.pl.ins": "",
	"S.f.anim.pl.loc": "",
	"S.f.anim.pl.nom": "",
	"S.f.anim.pl.voc": "",
	"S.f.anim.sg.acc": "",
	"S.f.anim.sg.dat": "",
	"S.f.anim.sg.gen": "",
	"S.f.anim.sg.ins": "",
	"S.f.anim.sg.loc": "",
	"S.f.anim.sg.nom": "",
	"S.f.anim.sg.nom.abbr": "",
	"S.f.anim.sg.nom.distort": "",
	"S.f.anim.sg.voc": "",
	"S.f.anim.sg.voc.anom": "",
	"S.f.anim.sg.voc.distort": "",
	"S.f.famn.anim.0.sg.acc": "",
	"S.f.famn.anim.0.sg.gen": "",
	"S.f.famn.anim.0.sg.ins": "",
	"S.f.famn.anim.0.sg.nom": "",
	"S.f.famn.anim.sg.gen": "",
	"S.f.famn.anim.sg.ins": "",
	"S.f.famn.anim.sg.nom": "",
	"S.f.inan.0.abbr": "",
	"S.f.inan.0.dat": "",
	"S.f.inan.0.pl.acc": "",
	"S.f.inan.0.pl.dat": "",
	"S.f.inan.0.pl.gen": "",
	"S.f.inan.0.pl.ins": "",
	"S.f.inan.0.pl.loc": "",
	"S.f.inan.0.pl.nom": "",
	"S.f.inan.0.sg.acc": "",
	"S.f.inan.0.sg.dat": "",
	"S.f.inan.0.sg.gen": "",
	"S.f.inan.0.sg.gen.abbr": "",
	"S.f.inan.0.sg.ins": "",
	"S.f.inan.0.sg.loc": "",
	"S.f.inan.0.sg.nom": "",
	"S.f.inan.0.sg.nom.distort": "",
	"S.f.inan.acc": "",
	"S.f.inan.gen": "",
	"S.f.inan.ins": "",
	"S.f.inan.nom": "",
	"S.f.inan.obsc.pl.nom": "",
	"S.f.inan.obsc.sg.acc": "",
	"S.f.inan.obsc.sg.gen": "",
	"S.f.inan.obsc.sg.ins": "",
	"S.f.inan.obsc.sg.nom": "",
	"S.f.inan.pl.acc": "",
	"S.f.inan.pl.acc.abbr": "",
	"S.f.inan.pl.acc.distort": "",
	"S.f.inan.pl.dat": "",
	"S.f.inan.pl.dat.abbr": "",
	"S.f.inan.pl.gen": "",
	"S.f.inan.pl.gen.abbr": "",
	"S.f.inan.pl.gen.anom": "",
	"S.f.inan.pl.gen.distort": "",
	"S.f.inan.pl.ins": "",
	"S.f.inan.pl.ins.anom": "",
	"S.f.inan.pl.ins.distort": "",
	"S.f.inan.pl.loc": "",
	"S.f.inan.pl.loc.abbr": "",
	"S.f.inan.pl.nom": "",
	"S.f.inan.pl.nom.abbr": "",
	"S.f.inan.pl.nom.ciph": "",
	"S.f.inan.pl.nom.distort": "",
	"S.f.inan.sg.acc": "",
	"S.f.inan.sg.acc.abbr": "",
	"S.f.inan.sg.acc.distort": "",
	"S.f.inan.sg.dat": "",
	"S.f.inan.sg.dat.abbr": "",
	"S.f.inan.sg.dat.anom": "",
	"S.f.inan.sg.dat.distort": "",
	"S.f.inan.sg.gen": "",
	"S.f.inan.sg.gen2": "",
	"S.f.inan.sg.gen.abbr": "",
	"S.f.inan.sg.gen.distort": "",
	"S.f.inan.sg.gen.obsc": "",
	"S.f.inan.sg.ins": "",
	"S.f.inan.sg.ins.abbr": "",
	"S.f.inan.sg.ins.anom": "",
	"S.f.inan.sg.loc": "",
	"S.f.inan.sg.loc2": "",
	"S.f.inan.sg.loc.abbr": "",
	"S.f.inan.sg.loc.distort": "",
	"S.f.inan.sg.nom": "",
	"S.f.inan.sg.nom.abbr": "",
	"S.f.inan.sg.nom.distort": "",
	"S.f.persn.anim.0.sg.dat": "",
	"S.f.persn.anim.0.sg.gen": "",
	"S.f.persn.anim.0.sg.ins": "",
	"S.f.persn.anim.0.sg.nom": "",
	"S.f.persn.anim.pl.nom": "",
	"S.f.persn.anim.sg.acc": "",
	"S.f.persn.anim.sg.dat": "",
	"S.f.persn.anim.sg.gen": "",
	"S.f.persn.anim.sg.loc": "",
	"S.f.persn.anim.sg.nom": "",
	"S.f.persn.inan.sg.nom": "",
	"S.f.pl.inan.acc": "",
	"S.f.pl.inan.gen": "",
	"S.f.pl.inan.loc": "",
	"S.f.pl.inan.nom": "",
	"S.f.sg.gen": "",
	"S.f.sg.loc": "",
	"S.f.sg.nom": "",
	"S.f.sg.nom.abbr": "",
	"S.inan.0.pl.gen": "",
	"S.inan.0.sg.gen": "",
	"S.inan.0.sg.loc": "",
	"S.inan.0.sg.m.acc": "",
	"S.inan.0.sg.nom": "",
	"S.inan.f.0.sg.gen": "",
	"S.inan.m.sg.gen": "",
	"S.inan.n.sg.nom": "",
	"S.inan.pl.0.acc": "",
	"S.inan.pl.0.dat": "",
	"S.inan.pl.0.gen": "",
	"S.inan.pl.0.loc": "",
	"S.inan.pl.0.nom": "",
	"S.inan.pl.acc": "",
	"S.inan.pl.gen": "",
	"S.inan.pl.loc": "",
	"S.inan.pl.n.acc": "",
	"S.inan.pl.nom": "",
	"S.inan.sg.acc": "",
	"S.inan.sg.gen": "",
	"S.inan.sg.loc": "",
	"S.inan.sg.nom": "",
	"S.inan.sg.nom.abbr": "",
	"S.m.0.sg.gen": "",
	"S.m.anim.0.pl.acc": "",
	"S.m.anim.0.pl.gen": "",
	"S.m.anim.0.pl.ins": "",
	"S.m.anim.0.pl.nom": "",
	"S.m.anim.0.sg.acc": "",
	"S.m.anim.0.sg.dat": "",
	"S.m.anim.0.sg.gen": "",
	"S.m.anim.0.sg.ins": "",
	"S.m.anim.0.sg.loc": "",
	"S.m.anim.0.sg.nom": "",
	"S.m.anim.obsc.pl.ins": "",
	"S.m.anim.obsc.pl.nom": "",
	"S.m.anim.obsc.sg.acc": "",
	"S.m.anim.obsc.sg.nom": "",
	"S.m.anim.pl.acc": "",
	"S.m.anim.pl.acc2": "",
	"S.m.anim.pl.acc.anom": "",
	"S.m.anim.pl.acc.distort": "",
	"S.m.anim.pl.dat": "",
	"S.m.anim.pl.dat.anom": "",
	"S.m.anim.pl.gen": "",
	"S.m.anim.pl.gen.abbr": "",
	"S.m.anim.pl.gen.anom": "",
	"S.m.anim.pl.ins": "",
	"S.m.anim.pl.ins.abbr": "",
	"S.m.anim.pl.ins.anom": "",
	"S.m.anim.pl.loc": "",
	"S.m.anim.pl.nom": "",
	"S.m.anim.pl.nom.anom": "",
	"S.m.anim.pl.nom.distort": "",
	"S.m.anim.sg.acc": "",
	"S.m.anim.sg.acc.anom": "",
	"S.m.anim.sg.dat": "",
	"S.m.anim.sg.dat.abbr": "",
	"S.m.anim.sg.gen": "",
	"S.m.anim.sg.gen.abbr": "",
	"S.m.anim.sg.gen.distort": "",
	"S.m.anim.sg.ins": "",
	"S.m.anim.sg.ins.abbr": "",
	"S.m.anim.sg.ins.distort": "",
	"S.m.anim.sg.loc": "",
	"S.m.anim.sg.nom": "",
	"S.m.anim.sg.nom.abbr": "",
	"S.m.anim.sg.nom.anom": "",
	"S.m.anim.sg.nom.distort": "",
	"S.m.anim.sg.voc": "",
	"S.m.anim.sg.voc.anom": "",
	"S.m.famn.anim.0.pl.dat": "",
	"S.m.famn.anim.0.sg.acc": "",
	"S.m.famn.anim.0.sg.dat": "",
	"S.m.famn.anim.0.sg.gen": "",
	"S.m.famn.anim.0.sg.ins": "",
	"S.m.famn.anim.0.sg.nom": "",
	"S.m.famn.anim.sg.acc": "",
	"S.m.famn.anim.sg.dat": "",
	"S.m.famn.anim.sg.gen": "",
	"S.m.famn.anim.sg.ins": "",
	"S.m.famn.anim.sg.loc": "",
	"S.m.famn.anim.sg.nom": "",
	"S.m.famn.sg.gen.anim": "",
	"S.m-f.anim.0.pl.gen": "",
	"S.m-f.anim.0.pl.nom": "",
	"S.m-f.anim.0.sg.dat": "",
	"S.m-f.anim.0.sg.dat.anom": "",
	"S.m-f.anim.0.sg.nom": "",
	"S.m-f.anim.pl.acc": "",
	"S.m-f.anim.pl.dat": "",
	"S.m-f.anim.pl.gen": "",
	"S.m-f.anim.pl.ins": "",
	"S.m-f.anim.pl.loc": "",
	"S.m-f.anim.pl.nom": "",
	"S.m-f.anim.sg.acc": "",
	"S.m-f.anim.sg.dat": "",
	"S.m-f.anim.sg.gen": "",
	"S.m-f.anim.sg.ins": "",
	"S.m-f.anim.sg.loc": "",
	"S.m-f.anim.sg.nom": "",
	"S.m-f.famn.anim.0.sg.acc": "",
	"S.m-f.famn.anim.0.sg.dat": "",
	"S.m-f.famn.anim.0.sg.gen": "",
	"S.m-f.famn.anim.0.sg.ins": "",
	"S.m-f.famn.anim.0.sg.nom": "",
	"S.m-f.famn.anim.sg.nom": "",
	"S.m-f.inan.pl.nom": "",
	"S.m-f.inan.sg.gen": "",
	"S.m.inan": "",
	"S.m.inan.0.pl.acc": "",
	"S.m.inan.0.pl.gen": "",
	"S.m.inan.0.pl.gen.abbr": "",
	"S.m.inan.0.pl.ins": "",
	"S.m.inan.0.pl.loc": "",
	"S.m.inan.0.pl.nom": "",
	"S.m.inan.0.sg.acc": "",
	"S.m.inan.0.sg.acc.abbr": "",
	"S.m.inan.0.sg.dat": "",
	"S.m.inan.0.sg.gen": "",
	"S.m.inan.0.sg.gen.abbr": "",
	"S.m.inan.0.sg.gen.anom": "",
	"S.m.inan.0.sg.ins": "",
	"S.m.inan.0.sg.loc": "",
	"S.m.inan.0.sg.nom": "",
	"S.m.inan.0.sg.nom.abbr": "",
	"S.m.inan.0.sg.nom.anom": "",
	"S.m.inan.obsc.pl.gen.abbr": "",
	"S.m.inan.obsc.sg.acc": "",
	"S.m.inan.obsc.sg.dat": "",
	"S.m.inan.obsc.sg.gen": "",
	"S.m.inan.obsc.sg.nom": "",
	"S.m.inan.pl.0.acc": "",
	"S.m.inan.pl.0.gen": "",
	"S.m.inan.pl.0.ins": "",
	"S.m.inan.pl.0.loc": "",
	"S.m.inan.pl.0.nom": "",
	"S.m.inan.pl.acc": "",
	"S.m.inan.pl.acc2": "",
	"S.m.inan.pl.acc.abbr": "",
	"S.m.inan.pl.acc.anom": "",
	"S.m.inan.pl.acc.ciph": "",
	"S.m.inan.pl.acc.ciph.abbr": "",
	"S.m.inan.pl.acc.distort": "",
	"S.m.inan.pl.dat": "",
	"S.m.inan.pl.dat.abbr": "",
	"S.m.inan.pl.gen": "",
	"S.m.inan.pl.gen.abbr": "",
	"S.m.inan.pl.gen.abbr.abbr": "",
	"S.m.inan.pl.gen.anom": "",
	"S.m.inan.pl.gen.distort": "",
	"S.m.inan.pl.ins": "",
	"S.m.inan.pl.ins.abbr": "",
	"S.m.inan.pl.loc": "",
	"S.m.inan.pl.loc2.abbr": "",
	"S.m.inan.pl.loc.abbr": "",
	"S.m.inan.pl.loc.anom": "",
	"S.m.inan.pl.nom": "",
	"S.m.inan.pl.nom.abbr": "",
	"S.m.inan.pl.nom.distort": "",
	"S.m.inan.sg.acc": "",
	"S.m.inan.sg.acc.abbr": "",
	"S.m.inan.sg.acc.distort": "",
	"S.m.inan.sg.adnum": "",
	"S.m.inan.sg.dat": "",
	"S.m.inan.sg.dat.abbr": "",
	"S.m.inan.sg.dat.anom": "",
	"S.m.inan.sg.gen": "",
	"S.m.inan.sg.gen2": "",
	"S.m.inan.sg.gen.abbr": "",
	"S.m.inan.sg.gen.anom": "",
	"S.m.inan.sg.gen.distort": "",
	"S.m.inan.sg.ins": "",
	"S.m.inan.sg.ins.abbr": "",
	"S.m.inan.sg.ins.anom": "",
	"S.m.inan.sg.ins.distort": "",
	"S.m.inan.sg.loc": "",
	"S.m.inan.sg.loc2": "",
	"S.m.inan.sg.loc2.abbr": "",
	"S.m.inan.sg.loc2.distort": "",
	"S.m.inan.sg.loc.abbr": "",
	"S.m.inan.sg.loc.anom": "",
	"S.m.inan.sg.loc.distort": "",
	"S.m.inan.sg.nom": "",
	"S.m.inan.sg.nom.abbr": "",
	"S.m.inan.sg.nom.distort": "",
	"S.m.persn.anim.0.sg.acc": "",
	"S.m.persn.anim.0.sg.dat": "",
	"S.m.persn.anim.0.sg.gen": "",
	"S.m.persn.anim.0.sg.nom": "",
	"S.m.persn.anim.sg.acc": "",
	"S.m.persn.anim.sg.dat": "",
	"S.m.persn.anim.sg.gen": "",
	"S.m.persn.anim.sg.ins": "",
	"S.m.persn.anim.sg.nom": "",
	"S.m.persn.inan.0.sg.dat": "",
	"S.m.pl.acc": "",
	"S.m.pl.dat": "",
	"S.m.pl.gen": "",
	"S.m.pl.inan.loc": "",
	"S.m.pl.nom": "",
	"S.m.sg.ins": "",
	"S.m.sg.nom.inan": "",
	"S.n.anim.0.sg.nom": "",
	"S.n.anim.pl.acc": "",
	"S.n.anim.pl.dat": "",
	"S.n.anim.pl.gen": "",
	"S.n.anim.pl.ins": "",
	"S.n.anim.pl.loc": "",
	"S.n.anim.pl.nom": "",
	"S.n.anim.sg.acc": "",
	"S.n.anim.sg.dat": "",
	"S.n.anim.sg.gen": "",
	"S.n.anim.sg.ins": "",
	"S.n.anim.sg.loc": "",
	"S.n.anim.sg.nom": "",
	"S.n.anim.sg.nom.ciph": "",
	"S.n.inan.0.pl.acc": "",
	"S.n.inan.0.pl.dat": "",
	"S.n.inan.0.pl.gen": "",
	"S.n.inan.0.pl.ins": "",
	"S.n.inan.0.pl.loc": "",
	"S.n.inan.0.pl.nom": "",
	"S.n.inan.0.pl.nom.anom": "",
	"S.n.inan.0.sg.acc": "",
	"S.n.inan.0.sg.dat": "",
	"S.n.inan.0.sg.gen": "",
	"S.n.inan.0.sg.gen.abbr": "",
	"S.n.inan.0.sg.gen.anom": "",
	"S.n.inan.0.sg.ins": "",
	"S.n.inan.0.sg.loc": "",
	"S.n.inan.0.sg.nom": "",
	"S.n.inan.obsc.sg.gen": "",
	"S.n.inan.obsc.sg.nom": "",
	"S.n.inan.pl.0.gen": "",
	"S.n.inan.pl.0.nom": "",
	"S.n.inan.pl.acc": "",
	"S.n.inan.pl.acc.anom": "",
	"S.n.inan.pl.dat": "",
	"S.n.inan.pl.gen": "",
	"S.n.inan.pl.gen.abbr": "",
	"S.n.inan.pl.gen.anom": "",
	"S.n.inan.pl.ins": "",
	"S.n.inan.pl.ins.ciph": "",
	"S.n.inan.pl.loc": "",
	"S.n.inan.pl.loc.anom": "",
	"S.n.inan.pl.nom": "",
	"S.n.inan.pl.nom.abbr": "",
	"S.n.inan.pl.nom.distort": "",
	"S.n.inan.sg.acc": "",
	"S.n.inan.sg.acc.abbr": "",
	"S.n.inan.sg.acc.anom": "",
	"S.n.inan.sg.acc.ciph": "",
	"S.n.inan.sg.acc.distort": "",
	"S.n.inan.sg.dat": "",
	"S.n.inan.sg.dat.abbr": "",
	"S.n.inan.sg.dat.ciph": "",
	"S.n.inan.sg.gen": "",
	"S.n.inan.sg.gen.abbr": "",
	"S.n.inan.sg.gen.ciph": "",
	"S.n.inan.sg.gen.distort": "",
	"S.n.inan.sg.ins": "",
	"S.n.inan.sg.ins.abbr": "",
	"S.n.inan.sg.ins.ciph": "",
	"S.n.inan.sg.loc": "",
	"S.n.inan.sg.loc.abbr": "",
	"S.n.inan.sg.loc.anom": "",
	"S.n.inan.sg.loc.ciph": "",
	"S.n.inan.sg.nom": "",
	"S.n.inan.sg.nom.abbr": "",
	"S.n.inan.sg.nom.ciph": "",
	"S.n.inan.sg.nom.distort": "",
	"S.n.sg.acc": "",
	"S.n.sg.acc.inan": "",
	"S.n.sg.gen": "",
	"S.n.sg.gen.anim": "",
	"S.n.sg.loc": "",
	"S.n.sg.nom": "",
	"S.n.sg.nom.anim": "",
	"S.patrn.f.anim.sg.acc": "",
	"S.patrn.f.anim.sg.acc.distort": "",
	"S.patrn.f.anim.sg.dat": "",
	"S.patrn.f.anim.sg.dat.anom": "",
	"S.patrn.f.anim.sg.gen": "",
	"S.patrn.f.anim.sg.gen.distort": "",
	"S.patrn.f.anim.sg.ins": "",
	"S.patrn.f.anim.sg.nom": "",
	"S.patrn.f.anim.sg.nom.distort": "",
	"S.patrn.m.anim.pl.nom": "",
	"S.patrn.m.anim.sg.acc": "",
	"S.patrn.m.anim.sg.acc.distort": "",
	"S.patrn.m.anim.sg.dat": "",
	"S.patrn.m.anim.sg.dat.distort": "",
	"S.patrn.m.anim.sg.gen": "",
	"S.patrn.m.anim.sg.ins": "",
	"S.patrn.m.anim.sg.loc": "",
	"S.patrn.m.anim.sg.nom": "",
	"S.patrn.m.anim.sg.nom.anom": "",
	"S.patrn.m.anim.sg.nom.distort": "",
	"S.persn.f.anim.0.sg.acc": "",
	"S.persn.f.anim.0.sg.dat": "",
	"S.persn.f.anim.0.sg.gen": "",
	"S.persn.f.anim.0.sg.ins": "",
	"S.persn.f.anim.0.sg.loc": "",
	"S.persn.f.anim.0.sg.nom": "",
	"S.persn.f.anim.gen": "",
	"S.persn.f.anim.pl.gen": "",
	"S.persn.f.anim.pl.ins": "",
	"S.persn.f.anim.pl.nom": "",
	"S.persn.f.anim.pl.voc": "",
	"S.persn.f.anim.sg.acc": "",
	"S.persn.f.anim.sg.dat": "",
	"S.persn.f.anim.sg.gen": "",
	"S.persn.f.anim.sg.ins": "",
	"S.persn.f.anim.sg.loc": "",
	"S.persn.f.anim.sg.nom": "",
	"S.persn.f.anim.sg.nom.distort": "",
	"S.persn.f.anim.sg.voc": "",
	"S.persn.m.anim.0.pl.ins": "",
	"S.persn.m.anim.0.sg.acc": "",
	"S.persn.m.anim.0.sg.dat": "",
	"S.persn.m.anim.0.sg.dat.anom": "",
	"S.persn.m.anim.0.sg.gen": "",
	"S.persn.m.anim.0.sg.ins": "",
	"S.persn.m.anim.0.sg.loc": "",
	"S.persn.m.anim.0.sg.nom": "",
	"S.persn.m.anim.0.sg.nom.distort": "",
	"S.persn.m.anim.gen": "",
	"S.persn.m.anim.pl.acc": "",
	"S.persn.m.anim.pl.gen": "",
	"S.persn.m.anim.pl.ins": "",
	"S.persn.m.anim.pl.nom": "",
	"S.persn.m.anim.pl.voc": "",
	"S.persn.m.anim.sg.acc": "",
	"S.persn.m.anim.sg.acc.anom": "",
	"S.persn.m.anim.sg.acc.distort": "",
	"S.persn.m.anim.sg.dat": "",
	"S.persn.m.anim.sg.dat.distort": "",
	"S.persn.m.anim.sg.gen": "",
	"S.persn.m.anim.sg.gen.abbr": "",
	"S.persn.m.anim.sg.gen.anom": "",
	"S.persn.m.anim.sg.gen.distort": "",
	"S.persn.m.anim.sg.ins": "",
	"S.persn.m.anim.sg.loc": "",
	"S.persn.m.anim.sg.nom": "",
	"S.persn.m.anim.sg.nom.abbr": "",
	"S.persn.m.anim.sg.nom.distort": "",
	"S.persn.m.anim.sg.voc": "",
	"S.persn.m.anim.sg.voc.distort": "",
	"S.persn.m.famn.anim.0.sg.gen": "",
	"S.persn.m-f.anim.sg.acc": "",
	"S.persn.m-f.anim.sg.dat": "",
	"S.persn.m-f.anim.sg.gen": "",
	"S.persn.m-f.anim.sg.ins": "",
	"S.persn.m-f.anim.sg.nom": "",
	"S.persn.m-f.anim.sg.voc.anom": "",
	"S.persn.n.inan.sg.loc": "",
	"S.persn.n.inan.sg.nom": "",
	"S.persn.pl.nom": "",
	"S.pl.0.acc": "",
	"S.pl.0.dat": "",
	"S.pl.0.gen": "",
	"S.pl.0.ins": "",
	"S.pl.0.loc": "",
	"S.pl.0.nom": "",
	"S.pl.acc": "",
	"S.pl.anim.0.gen": "",
	"S.pl.anim.dat": "",
	"S.pl.anim.gen": "",
	"S.pl.dat": "",
	"S.pl.gen": "",
	"S.pl.gen.anom": "",
	"S.pl.inan.0.gen": "",
	"S.pl.inan.0.nom": "",
	"S.pl.inan.acc": "",
	"S.pl.inan.dat": "",
	"S.pl.inan.gen": "",
	"S.pl.inan.loc": "",
	"S.pl.inan.nom": "",
	"S.pl.ins": "",
	"S.pl.loc": "",
	"S.pl.loc.distort": "",
	"S.pl.nom": "",
	"S.pl.nom.abbr": "",
	"S-PRO.2p.sg.dat.distort": "",
	"S-PRO.acc": "",
	"S-PRO.anim.pl.gen.abbr": "",
	"S-PRO.dat": "",
	"S-PRO.f.anim.sg.nom": "",
	"S-PRO.f.sg.3p.acc": "",
	"S-PRO.f.sg.3p.dat": "",
	"S-PRO.f.sg.3p.gen": "",
	"S-PRO.f.sg.3p.ins": "",
	"S-PRO.f.sg.3p.loc": "",
	"S-PRO.f.sg.3p.nom": "",
	"S-PRO.f.sg.acc": "",
	"S-PRO.f.sg.gen": "",
	"S-PRO.f.sg.nom": "",
	"S-PRO.gen": "",
	"S-PRO.ins": "",
	"S-PRO.loc": "",
	"S-PRO.m.anim.sg.3p.gen.distort": "",
	"S-PRO.m.anim.sg.acc": "",
	"S-PRO.m.anim.sg.dat": "",
	"S-PRO.m.anim.sg.gen": "",
	"S-PRO.m.anim.sg.ins": "",
	"S-PRO.m.anim.sg.nom": "",
	"S-PRO.m.pl.3p.dat": "",
	"S-PRO.m.sg.3p.acc": "",
	"S-PRO.m.sg.3p.dat": "",
	"S-PRO.m.sg.3p.gen": "",
	"S-PRO.m.sg.3p.ins": "",
	"S-PRO.m.sg.3p.loc": "",
	"S-PRO.m.sg.3p.nom": "",
	"S-PRO.m.sg.acc": "",
	"S-PRO.m.sg.anim.3p.nom": "",
	"S-PRO.m.sg.anim.acc": "",
	"S-PRO.m.sg.dat": "",
	"S-PRO.m.sg.gen": "",
	"S-PRO.m.sg.ins": "",
	"S-PRO.m.sg.loc": "",
	"S-PRO.m.sg.nom": "",
	"S-PRO.n.inan.pl.acc": "",
	"S-PRO.n.inan.pl.acc.abbr": "",
	"S-PRO.n.inan.pl.nom.abbr": "",
	"S-PRO.n.inan.sg.acc": "",
	"S-PRO.n.inan.sg.dat": "",
	"S-PRO.n.inan.sg.gen": "",
	"S-PRO.n.inan.sg.ins": "",
	"S-PRO.n.inan.sg.ins.abbr": "",
	"S-PRO.n.inan.sg.loc": "",
	"S-PRO.n.inan.sg.nom": "",
	"S-PRO.n.inan.sg.nom.abbr": "",
	"S-PRO.n.sg": "",
	"S-PRO.n.sg.3p.acc": "",
	"S-PRO.n.sg.3p.dat": "",
	"S-PRO.n.sg.3p.gen": "",
	"S-PRO.n.sg.3p.ins": "",
	"S-PRO.n.sg.3p.loc": "",
	"S-PRO.n.sg.3p.nom": "",
	"S-PRO.n.sg.acc": "",
	"S-PRO.n.sg.acc.anom": "",
	"S-PRO.n.sg.acc.distort": "",
	"S-PRO.n.sg.dat": "",
	"S-PRO.n.sg.dat.abbr": "",
	"S-PRO.n.sg.gen": "",
	"S-PRO.n.sg.gen.abbr": "",
	"S-PRO.n.sg.gen.distort": "",
	"S-PRO.n.sg.inan.nom": "",
	"S-PRO.n.sg.inan.nom.abbr": "",
	"S-PRO.n.sg.ins": "",
	"S-PRO.n.sg.ins.anom": "",
	"S-PRO.n.sg.loc": "",
	"S-PRO.n.sg.nom": "",
	"S-PRO.n.sg.nom.abbr": "",
	"S-PRO.n.sg.nom.anom": "",
	"S-PRO.n.sg.nom.distort": "",
	"S-PRO.pl.1p.acc": "",
	"S-PRO.pl.1p.acc.distort": "",
	"S-PRO.pl.1p.dat": "",
	"S-PRO.pl.1p.gen": "",
	"S-PRO.pl.1p.ins": "",
	"S-PRO.pl.1p.loc": "",
	"S-PRO.pl.1p.nom": "",
	"S-PRO.pl.2p.acc": "",
	"S-PRO.pl.2p.dat": "",
	"S-PRO.pl.2p.gen": "",
	"S-PRO.pl.2p.ins": "",
	"S-PRO.pl.2p.loc": "",
	"S-PRO.pl.2p.nom": "",
	"S-PRO.pl.3p.acc": "",
	"S-PRO.pl.3p.dat": "",
	"S-PRO.pl.3p.gen": "",
	"S-PRO.pl.3p.ins": "",
	"S-PRO.pl.3p.loc": "",
	"S-PRO.pl.3p.nom": "",
	"S-PRO.pl.acc": "",
	"S-PRO.pl.anim.1p.acc": "",
	"S-PRO.pl.anim.1p.dat": "",
	"S-PRO.pl.anim.1p.gen": "",
	"S-PRO.pl.anim.1p.ins": "",
	"S-PRO.pl.anim.1p.loc": "",
	"S-PRO.pl.anim.1p.nom": "",
	"S-PRO.pl.anim.2p.acc": "",
	"S-PRO.pl.anim.2p.dat": "",
	"S-PRO.pl.anim.2p.gen": "",
	"S-PRO.pl.anim.2p.nom": "",
	"S-PRO.pl.anim.dat": "",
	"S-PRO.pl.anim.nom": "",
	"S-PRO.pl.dat": "",
	"S-PRO.pl.gen": "",
	"S-PRO.pl.ins": "",
	"S-PRO.pl.ins.abbr": "",
	"S-PRO.pl.loc": "",
	"S-PRO.pl.nom": "",
	"S-PRO.pl.nom.abbr": "",
	"S-PRO.pl.nom.distort": "",
	"S-PRO.sg.1p.acc": "",
	"S-PRO.sg.1p.dat": "",
	"S-PRO.sg.1p.gen": "",
	"S-PRO.sg.1p.ins": "",
	"S-PRO.sg.1p.loc": "",
	"S-PRO.sg.1p.nom": "",
	"S-PRO.sg.1p.nom.distort": "",
	"S-PRO.sg.2p.acc": "",
	"S-PRO.sg.2p.acc.anom": "",
	"S-PRO.sg.2p.dat": "",
	"S-PRO.sg.2p.dat.anom": "",
	"S-PRO.sg.2p.dat.distort": "",
	"S-PRO.sg.2p.gen": "",
	"S-PRO.sg.2p.gen.distort": "",
	"S-PRO.sg.2p.ins": "",
	"S-PRO.sg.2p.loc": "",
	"S-PRO.sg.2p.nom": "",
	"S-PRO.sg.2p.nom.distort": "",
	"S-PRO.sg.3p.acc": "",
	"S-PRO.sg.3p.acc.anom": "",
	"S-PRO.sg.acc": "",
	"S-PRO.sg.anim.1p.acc": "",
	"S-PRO.sg.anim.1p.dat": "",
	"S-PRO.sg.anim.1p.gen": "",
	"S-PRO.sg.anim.1p.ins": "",
	"S-PRO.sg.anim.1p.loc": "",
	"S-PRO.sg.anim.1p.nom": "",
	"S-PRO.sg.anim.2p.acc": "",
	"S-PRO.sg.anim.2p.dat": "",
	"S-PRO.sg.anim.2p.gen": "",
	"S-PRO.sg.anim.2p.ins": "",
	"S-PRO.sg.anim.2p.loc": "",
	"S-PRO.sg.anim.2p.nom": "",
	"S-PRO.sg.dat": "",
	"S-PRO.sg.f.3p.acc": "",
	"S-PRO.sg.f.3p.dat": "",
	"S-PRO.sg.f.3p.gen": "",
	"S-PRO.sg.f.3p.gen.anom": "",
	"S-PRO.sg.f.3p.ins": "",
	"S-PRO.sg.f.3p.loc": "",
	"S-PRO.sg.f.3p.nom": "",
	"S-PRO.sg.gen": "",
	"S-PRO.sg.ins": "",
	"S-PRO.sg.loc": "",
	"S-PRO.sg.m.3p.acc": "",
	"S-PRO.sg.m.3p.dat": "",
	"S-PRO.sg.m.3p.gen": "",
	"S-PRO.sg.m.3p.ins": "",
	"S-PRO.sg.m.3p.loc": "",
	"S-PRO.sg.m.3p.nom": "",
	"S-PRO.sg.m.acc": "",
	"S-PRO.sg.m.dat": "",
	"S-PRO.sg.m.gen": "",
	"S-PRO.sg.m.nom": "",
	"S-PRO.sg.n.3p.acc": "",
	"S-PRO.sg.n.3p.dat": "",
	"S-PRO.sg.n.3p.gen": "",
	"S-PRO.sg.n.3p.ins": "",
	"S-PRO.sg.n.3p.loc": "",
	"S-PRO.sg.n.3p.nom": "",
	"S-PRO.sg.n.acc": "",
	"S-PRO.sg.n.acc.distort": "",
	"S-PRO.sg.n.gen": "",
	"S-PRO.sg.n.inan.nom": "",
	"S-PRO.sg.n.ins": "",
	"S-PRO.sg.n.nom": "",
	"S-PRO.sg.n.nom.distort": "",
	"S-PRO.sg.nom": "",
	"S.zoon.f.anim.0.sg.acc": "",
	"S.zoon.f.anim.0.sg.nom": "",
	"S.zoon.f.anim.sg.acc": "",
	"S.zoon.f.anim.sg.nom": "",
	"S.zoon.m.anim.sg.acc": "",
	"S.zoon.m.anim.sg.nom": "",
	"V.intr.act.ipf.f.sg.praet.indic": "",
	"V.intr.ipf.act.imper.sg.1p.distort": "",
	"V.intr.ipf.act.indic.praet.sg.m": "",
	"V.intr.ipf.act.sg.praes.3p.indic.abbr": "",
	"V.intr.ipf.fut.3p.sg.indic": "",
	"V.intr.ipf.fut.pl.1p.act.indic": "",
	"V.intr.ipf.fut.pl.2p.act.indic": "",
	"V.intr.ipf.fut.pl.3p.act.indic": "",
	"V.intr.ipf.fut.sg.1p.act.indic": "",
	"V.intr.ipf.fut.sg.2p.act.indic": "",
	"V.intr.ipf.fut.sg.3p.act.indic": "",
	"V.intr.ipf.ger.praes.act": "",
	"V.intr.ipf.imper.pl.2p.act": "",
	"V.intr.ipf.imper.sg.2p.act": "",
	"V.intr.ipf.inf.act": "",
	"V.intr.ipf.med.ger.praes": "",
	"V.intr.ipf.med.imper.pl.2p": "",
	"V.intr.ipf.med.imper.sg.2p": "",
	"V.intr.ipf.med.inf": "",
	"V.intr.ipf.med.partcp.praes.pl.acc.inan": "",
	"V.intr.ipf.med.partcp.praes.pl.gen": "",
	"V.intr.ipf.med.partcp.praes.pl.ins": "",
	"V.intr.ipf.med.partcp.praes.pl.loc": "",
	"V.intr.ipf.med.partcp.praes.pl.nom": "",
	"V.intr.ipf.med.partcp.praes.sg.f.ins": "",
	"V.intr.ipf.med.partcp.praes.sg.f.nom": "",
	"V.intr.ipf.med.partcp.praes.sg.m.gen": "",
	"V.intr.ipf.med.partcp.praes.sg.m.nom": "",
	"V.intr.ipf.med.partcp.praes.sg.n.dat": "",
	"V.intr.ipf.med.partcp.praes.sg.n.gen": "",
	"V.intr.ipf.med.partcp.praes.sg.n.loc": "",
	"V.intr.ipf.med.partcp.praet.sg.f.nom": "",
	"V.intr.ipf.med.praes.pl.2p.indic": "",
	"V.intr.ipf.med.praes.pl.3p.indic": "",
	"V.intr.ipf.med.praes.sg.1p.indic": "",
	"V.intr.ipf.med.praes.sg.2p.indic": "",
	"V.intr.ipf.med.praes.sg.3p.indic": "",
	"V.intr.ipf.med.praet.pl.indic": "",
	"V.intr.ipf.med.praet.sg.f.indic": "",
	"V.intr.ipf.med.praet.sg.m.indic": "",
	"V.intr.ipf.med.praet.sg.n.indic": "",
	"V.intr.ipf.partcp.praes.pl.acc.inan.act": "",
	"V.intr.ipf.partcp.praes.pl.dat.act": "",
	"V.intr.ipf.partcp.praes.pl.gen.act": "",
	"V.intr.ipf.partcp.praes.pl.ins.act": "",
	"V.intr.ipf.partcp.praes.pl.loc.act": "",
	"V.intr.ipf.partcp.praes.pl.nom.act": "",
	"V.intr.ipf.partcp.praes.sg.f.acc.act": "",
	"V.intr.ipf.partcp.praes.sg.f.dat.act": "",
	"V.intr.ipf.partcp.praes.sg.f.gen.act": "",
	"V.intr.ipf.partcp.praes.sg.f.ins.act": "",
	"V.intr.ipf.partcp.praes.sg.f.nom.act": "",
	"V.intr.ipf.partcp.praes.sg.m.acc.anim.act": "",
	"V.intr.ipf.partcp.praes.sg.m.acc.inan.act": "",
	"V.intr.ipf.partcp.praes.sg.m.dat.act": "",
	"V.intr.ipf.partcp.praes.sg.m.gen.act": "",
	"V.intr.ipf.partcp.praes.sg.m.ins.act": "",
	"V.intr.ipf.partcp.praes.sg.m.loc.act": "",
	"V.intr.ipf.partcp.praes.sg.m.nom.act": "",
	"V.intr.ipf.partcp.praes.sg.n.acc.act": "",
	"V.intr.ipf.partcp.praes.sg.n.dat.act": "",
	"V.intr.ipf.partcp.praes.sg.n.ins.act": "",
	"V.intr.ipf.partcp.praes.sg.n.nom.act": "",
	"V.intr.ipf.partcp.praet.pl.acc.anim.act": "",
	"V.intr.ipf.partcp.praet.pl.acc.inan.act": "",
	"V.intr.ipf.partcp.praet.pl.dat.act": "",
	"V.intr.ipf.partcp.praet.pl.gen.act": "",
	"V.intr.ipf.partcp.praet.pl.nom.act": "",
	"V.intr.ipf.partcp.praet.sg.f.acc.act": "",
	"V.intr.ipf.partcp.praet.sg.f.dat.act": "",
	"V.intr.ipf.partcp.praet.sg.f.nom.act": "",
	"V.intr.ipf.partcp.praet.sg.m.acc.inan.act": "",
	"V.intr.ipf.partcp.praet.sg.m.nom.act": "",
	"V.intr.ipf.partcp.praet.sg.n.nom.act": "",
	"V.intr.ipf.praes.pl.1p.act.indic": "",
	"V.intr.ipf.praes.pl.2p.act.indic": "",
	"V.intr.ipf.praes.pl.3p.act.indic": "",
	"V.intr.ipf.praes.sg.1p.act.indic": "",
	"V.intr.ipf.praes.sg.2p.act.indic": "",
	"V.intr.ipf.praes.sg.3p.act.indic": "",
	"V.intr.ipf.praet.pl.act.indic": "",
	"V.intr.ipf.praet.sg.f.act.indic": "",
	"V.intr.ipf.praet.sg.m.act.indic": "",
	"V.intr.ipf.praet.sg.n.act.indic": "",
	"V.intr.med.f.sg.pf.praet.indic": "",
	"V.intr.med.ger.ipf.praet": "",
	"V.intr.med.inf.pf": "",
	"V.intr.med.ipf.ger.praes": "",
	"V.intr.med.ipf.imper.pl.2p": "",
	"V.intr.med.ipf.imper.sg.2p": "",
	"V.intr.med.ipf.inf": "",
	"V.intr.med.ipf.partcp.praes.pl.nom": "",
	"V.intr.med.ipf.partcp.praes.sg.f.nom": "",
	"V.intr.med.ipf.partcp.praes.sg.m.ins": "",
	"V.intr.med.ipf.partcp.praes.sg.n.nom": "",
	"V.intr.med.ipf.partcp.praet.pl.gen": "",
	"V.intr.med.ipf.praes.pl.1p.indic": "",
	"V.intr.med.ipf.praes.pl.3p.indic": "",
	"V.intr.med.ipf.praes.sg.1p.indic": "",
	"V.intr.med.ipf.praes.sg.2p.indic": "",
	"V.intr.med.ipf.praes.sg.3p.indic": "",
	"V.intr.med.ipf.praet.pl.indic": "",
	"V.intr.med.ipf.praet.sg.f.indic": "",
	"V.intr.med.ipf.praet.sg.m.indic": "",
	"V.intr.med.ipf.praet.sg.n.indic": "",
	"V.intr.med.m.sg.pf.praet.indic": "",
	"V.intr.med.n.sg.pf.praet.indic": "",
	"V.intr.med.partcp.f.sg.nom.pf.praet.plen": "",
	"V.intr.med.partcp.m.sg.acc.pf.praet.plen": "",
	"V.intr.med.partcp.m.sg.nom.pf.praet.plen": "",
	"V.intr.med.partcp.n.sg.acc.pf.praet.plen": "",
	"V.intr.med.partcp.pl.nom.pf.praet.plen": "",
	"V.intr.med.pf.fut.sg.3p.indic": "",
	"V.intr.med.pf.inf": "",
	"V.intr.med.pf.praet.pl.indic": "",
	"V.intr.med.pf.praet.sg.m.indic": "",
	"V.intr.med.pl.pf.2p.imper": "",
	"V.intr.med.pl.pf.fut.2p.indic": "",
	"V.intr.med.pl.pf.fut.3p.indic": "",
	"V.intr.med.pl.pf.praet.indic": "",
	"V.intr.med.praet.pl.ipf.indic": "",
	"V.intr.med.sg.pf.2p.imper": "",
	"V.intr.med.sg.pf.fut.3p.indic": "",
	"V.intr.pf.fut.pl.1p.act.indic": "",
	"V.intr.pf.fut.sg.1p.act.indic": "",
	"V.intr.pf.fut.sg.2p.act.indic": "",
	"V.intr.pf.fut.sg.3p.act.indic": "",
	"V.intr.pf.ger.praet.act": "",
	"V.intr.pf.imper.pl.2p.act": "",
	"V.intr.pf.imper.sg.2p.act": "",
	"V.intr.pf.inf.act": "",
	"V.intr.pf.med.fut.pl.1p.indic": "",
	"V.intr.pf.med.fut.sg.1p.indic": "",
	"V.intr.pf.med.fut.sg.2p.indic": "",
	"V.intr.pf.med.fut.sg.3p.indic": "",
	"V.intr.pf.med.ger.praet": "",
	"V.intr.pf.med.inf": "",
	"V.intr.pf.med.partcp.praet.pl.gen": "",
	"V.intr.pf.med.partcp.praet.sg.f.acc": "",
	"V.intr.pf.med.partcp.praet.sg.f.ins": "",
	"V.intr.pf.med.praet.pl.indic": "",
	"V.intr.pf.med.praet.sg.f.indic": "",
	"V.intr.pf.med.praet.sg.m.indic": "",
	"V.intr.pf.med.praet.sg.n.indic": "",
	"V.intr.pf.partcp.praet.pl.acc.anim.act": "",
	"V.intr.pf.partcp.praet.pl.acc.inan.act": "",
	"V.intr.pf.partcp.praet.pl.gen.act": "",
	"V.intr.pf.partcp.praet.pl.ins.act": "",
	"V.intr.pf.partcp.praet.pl.loc.act": "",
	"V.intr.pf.partcp.praet.pl.nom.act": "",
	"V.intr.pf.partcp.praet.sg.f.acc.act": "",
	"V.intr.pf.partcp.praet.sg.f.gen.act": "",
	"V.intr.pf.partcp.praet.sg.f.nom.act": "",
	"V.intr.pf.partcp.praet.sg.m.acc.anim.act": "",
	"V.intr.pf.partcp.praet.sg.m.nom.act": "",
	"V.intr.pf.partcp.praet.sg.n.acc.act": "",
	"V.intr.pf.partcp.praet.sg.n.gen.act": "",
	"V.intr.pf.praet.pl.act.indic": "",
	"V.intr.pf.praet.sg.f.act.indic": "",
	"V.intr.pf.praet.sg.m.act.indic": "",
	"V.intr.pf.praet.sg.n.act.indic": "",
	"V.intr.praet.pl.ipf.act.indic": "",
	"V.ipf.act.indic.praes.pl.1p.distort": "",
	"V.ipf.act.indic.praes.sg.2p.distort": "",
	"V.ipf.act.indic.praes.sg.3p.distort": "",
	"V.ipf.act.indic.praet.sg.f.distort": "",
	"V.ipf.act.pl.intr.1p.imper": "",
	"V.ipf.f.sg.intr.act.praet.indic": "",
	"V.ipf.ger.praes.act": "",
	"V.ipf.imper.sg.2p.act": "",
	"V.ipf.inf.act": "",
	"V.ipf.inf.intr.act": "",
	"V.ipf.intr.act.f.sg.praet.indic": "",
	"V.ipf.intr.act.fut.sg.1p.indic.anom": "",
	"V.ipf.intr.act.ger.praes": "",
	"V.ipf.intr.act.ger.praes.anom": "",
	"V.ipf.intr.act.ger.praet": "",
	"V.ipf.intr.act.ger.praet.anom": "",
	"V.ipf.intr.act.indic.praes.3p.sg": "",
	"V.ipf.intr.act.indic.praes.3p.sg.abbr": "",
	"V.ipf.intr.act.indic.praet.sg.n": "",
	"V.ipf.intr.act.indic.sg.n.praet": "",
	"V.ipf.intr.act.inf": "",
	"V.ipf.intr.act.m.sg.praet.indic": "",
	"V.ipf.intr.act.n.sg.praet.indic": "",
	"V.ipf.intr.act.obsc.pl.praes.3p.indic": "",
	"V.ipf.intr.act.partcp.f.sg.acc.praes": "",
	"V.ipf.intr.act.partcp.f.sg.acc.praes.plen": "",
	"V.ipf.intr.act.partcp.f.sg.acc.praet": "",
	"V.ipf.intr.act.partcp.f.sg.acc.praet.plen": "",
	"V.ipf.intr.act.partcp.f.sg.dat.praes": "",
	"V.ipf.intr.act.partcp.f.sg.dat.praes.plen": "",
	"V.ipf.intr.act.partcp.f.sg.dat.praet.plen": "",
	"V.ipf.intr.act.partcp.f.sg.gen.praes": "",
	"V.ipf.intr.act.partcp.f.sg.gen.praes.plen": "",
	"V.ipf.intr.act.partcp.f.sg.gen.praet": "",
	"V.ipf.intr.act.partcp.f.sg.gen.praet.plen": "",
	"V.ipf.intr.act.partcp.f.sg.ins.praes": "",
	"V.ipf.intr.act.partcp.f.sg.ins.praes.plen": "",
	"V.ipf.intr.act.partcp.f.sg.ins.praet": "",
	"V.ipf.intr.act.partcp.f.sg.ins.praet.plen": "",
	"V.ipf.intr.act.partcp.f.sg.loc.praes": "",
	"V.ipf.intr.act.partcp.f.sg.loc.praes.plen": "",
	"V.ipf.intr.act.partcp.f.sg.loc.praet": "",
	"V.ipf.intr.act.partcp.f.sg.loc.praet.plen": "",
	"V.ipf.intr.act.partcp.f.sg.nom.praes": "",
	"V.ipf.intr.act.partcp.f.sg.nom.praes.plen": "",
	"V.ipf.intr.act.partcp.f.sg.nom.praet": "",
	"V.ipf.intr.act.partcp.f.sg.nom.praet.plen": "",
	"V.ipf.intr.act.partcp.m.praes.sg.acc.plen": "",
	"V.ipf.intr.act.partcp.m.sg.acc.praes": "",
	"V.ipf.intr.act.partcp.m.sg.acc.praes.plen": "",
	"V.ipf.intr.act.partcp.m.sg.acc.praet": "",
	"V.ipf.intr.act.partcp.m.sg.acc.praet.plen": "",
	"V.ipf.intr.act.partcp.m.sg.dat.praes": "",
	"V.ipf.intr.act.partcp.m.sg.dat.praes.plen": "",
	"V.ipf.intr.act.partcp.m.sg.dat.praet.plen": "",
	"V.ipf.intr.act.partcp.m.sg.gen.praes": "",
	"V.ipf.intr.act.partcp.m.sg.gen.praes.plen": "",
	"V.ipf.intr.act.partcp.m.sg.gen.praet.plen": "",
	"V.ipf.intr.act.partcp.m.sg.ins.praes": "",
	"V.ipf.intr.act.partcp.m.sg.ins.praes.plen": "",
	"V.ipf.intr.act.partcp.m.sg.ins.praet.plen": "",
	"V.ipf.intr.act.partcp.m.sg.loc.praes.plen": "",
	"V.ipf.intr.act.partcp.m.sg.nom.praes": "",
	"V.ipf.intr.act.partcp.m.sg.nom.praes.plen": "",
	"V.ipf.intr.act.partcp.m.sg.nom.praet": "",
	"V.ipf.intr.act.partcp.m.sg.nom.praet.plen": "",
	"V.ipf.intr.act.partcp.n.sg.acc.praes": "",
	"V.ipf.intr.act.partcp.n.sg.acc.praes.plen": "",
	"V.ipf.intr.act.partcp.n.sg.acc.praet.plen": "",
	"V.ipf.intr.act.partcp.n.sg.dat.praes.plen": "",
	"V.ipf.intr.act.partcp.n.sg.gen.praes": "",
	"V.ipf.intr.act.partcp.n.sg.gen.praes.plen": "",
	"V.ipf.intr.act.partcp.n.sg.gen.praet.plen": "",
	"V.ipf.intr.act.partcp.n.sg.ins.praes.plen": "",
	"V.ipf.intr.act.partcp.n.sg.ins.praet.plen": "",
	"V.ipf.intr.act.partcp.n.sg.loc.praes.plen": "",
	"V.ipf.intr.act.partcp.n.sg.nom.praes": "",
	"V.ipf.intr.act.partcp.n.sg.nom.praes.plen": "",
	"V.ipf.intr.act.partcp.n.sg.nom.praet": "",
	"V.ipf.intr.act.partcp.n.sg.nom.praet.plen": "",
	"V.ipf.intr.act.partcp.pl.acc.praes": "",
	"V.ipf.intr.act.partcp.pl.acc.praes.plen": "",
	"V.ipf.intr.act.partcp.pl.acc.praet": "",
	"V.ipf.intr.act.partcp.pl.acc.praet.plen": "",
	"V.ipf.intr.act.partcp.pl.dat.praes": "",
	"V.ipf.intr.act.partcp.pl.dat.praes.plen": "",
	"V.ipf.intr.act.partcp.pl.dat.praet": "",
	"V.ipf.intr.act.partcp.pl.dat.praet.plen": "",
	"V.ipf.intr.act.partcp.pl.gen.praes": "",
	"V.ipf.intr.act.partcp.pl.gen.praes.plen": "",
	"V.ipf.intr.act.partcp.pl.gen.praet": "",
	"V.ipf.intr.act.partcp.pl.gen.praet.plen": "",
	"V.ipf.intr.act.partcp.pl.ins.praes": "",
	"V.ipf.intr.act.partcp.pl.ins.praes.plen": "",
	"V.ipf.intr.act.partcp.pl.ins.praet.plen": "",
	"V.ipf.intr.act.partcp.pl.loc.praes.plen": "",
	"V.ipf.intr.act.partcp.pl.loc.praet.plen": "",
	"V.ipf.intr.act.partcp.pl.nom.praes": "",
	"V.ipf.intr.act.partcp.pl.nom.praes.plen": "",
	"V.ipf.intr.act.partcp.pl.nom.praet": "",
	"V.ipf.intr.act.partcp.pl.nom.praet.plen": "",
	"V.ipf.intr.act.partcp.praes.sg.m.nom.plen": "",
	"V.ipf.intr.act.partcp.sg.ins.praes.plen": "",
	"V.ipf.intr.act.pl.1p.imper": "",
	"V.ipf.intr.act.pl.1p.imper2": "",
	"V.ipf.intr.act.pl.2p.imper": "",
	"V.ipf.intr.act.pl.fut.1p.indic": "",
	"V.ipf.intr.act.pl.fut.2p.indic": "",
	"V.ipf.intr.act.pl.fut.3p.indic": "",
	"V.ipf.intr.act.pl.praes.1p.indic": "",
	"V.ipf.intr.act.pl.praes.2p.indic": "",
	"V.ipf.intr.act.pl.praes.3p.indic": "",
	"V.ipf.intr.act.pl.praes.3p.indic.abbr": "",
	"V.ipf.intr.act.pl.praes.3p.indic.anom": "",
	"V.ipf.intr.act.pl.praes.indic": "",
	"V.ipf.intr.act.pl.praet.indic": "",
	"V.ipf.intr.act.praes.3p.sg.indic.abbr": "",
	"V.ipf.intr.act.praes.sg.3p.abbr.indic": "",
	"V.ipf.intr.act.praes.sg.3p.indic": "",
	"V.ipf.intr.act.praes.sg.3p.indic.abbr": "",
	"V.ipf.intr.act.praet.m.sg.indic": "",
	"V.ipf.intr.act.praet.m.sg.indic.anom": "",
	"V.ipf.intr.act.praet.pl.indic": "",
	"V.ipf.intr.act.sg.1p.imper": "",
	"V.ipf.intr.act.sg.2p.imper": "",
	"V.ipf.intr.act.sg.2p.imper.abbr": "",
	"V.ipf.intr.act.sg.2p.imper.anom": "",
	"V.ipf.intr.act.sg.2p.imper.distort": "",
	"V.ipf.intr.act.sg.3p.praes.indic": "",
	"V.ipf.intr.act.sg.fut.1p.indic": "",
	"V.ipf.intr.act.sg.fut.2p.indic": "",
	"V.ipf.intr.act.sg.fut.3p.indic": "",
	"V.ipf.intr.act.sg.n.praet.indic": "",
	"V.ipf.intr.act.sg.praes.1p.indic": "",
	"V.ipf.intr.act.sg.praes.2p.indic": "",
	"V.ipf.intr.act.sg.praes.2p.indic.distort": "",
	"V.ipf.intr.act.sg.praes.3p.indic": "",
	"V.ipf.intr.act.sg.praes.3p.indic.abbr": "",
	"V.ipf.intr.act.sg.praes.3p.indic.anom": "",
	"V.ipf.intr.act.sg.praes.3p.indic.distort": "",
	"V.ipf.intr.f.sg.act.praet.indic": "",
	"V.ipf.intr.ger.act.praes": "",
	"V.ipf.intr.inf.act": "",
	"V.ipf.intr.med.f.sg.praet.indic": "",
	"V.ipf.intr.med.ger.praes": "",
	"V.ipf.intr.med.inf": "",
	"V.ipf.intr.med.inf.anom": "",
	"V.ipf.intr.med.m.sg.praet.indic": "",
	"V.ipf.intr.med.m.sg.praet.indic.abbr": "",
	"V.ipf.intr.med.n.sg.praet.indic": "",
	"V.ipf.intr.med.n.sg.praet.indic.anom": "",
	"V.ipf.intr.med.obsc.indic.praes.3p.sg.abbr": "",
	"V.ipf.intr.med.partcp.f.sg.acc.praes": "",
	"V.ipf.intr.med.partcp.f.sg.acc.praes.plen": "",
	"V.ipf.intr.med.partcp.f.sg.acc.praet.plen": "",
	"V.ipf.intr.med.partcp.f.sg.dat.praes": "",
	"V.ipf.intr.med.partcp.f.sg.dat.praes.plen": "",
	"V.ipf.intr.med.partcp.f.sg.gen.praes": "",
	"V.ipf.intr.med.partcp.f.sg.gen.praes.plen": "",
	"V.ipf.intr.med.partcp.f.sg.gen.praet.plen": "",
	"V.ipf.intr.med.partcp.f.sg.ins.praes": "",
	"V.ipf.intr.med.partcp.f.sg.ins.praes.plen": "",
	"V.ipf.intr.med.partcp.f.sg.ins.praet": "",
	"V.ipf.intr.med.partcp.f.sg.ins.praet.plen": "",
	"V.ipf.intr.med.partcp.f.sg.loc.praes.plen": "",
	"V.ipf.intr.med.partcp.f.sg.nom.praes": "",
	"V.ipf.intr.med.partcp.f.sg.nom.praes.plen": "",
	"V.ipf.intr.med.partcp.f.sg.nom.praet": "",
	"V.ipf.intr.med.partcp.f.sg.nom.praet.plen": "",
	"V.ipf.intr.med.partcp.m.sg.acc.praes": "",
	"V.ipf.intr.med.partcp.m.sg.acc.praes.plen": "",
	"V.ipf.intr.med.partcp.m.sg.acc.praet": "",
	"V.ipf.intr.med.partcp.m.sg.acc.praet.plen": "",
	"V.ipf.intr.med.partcp.m.sg.dat.praes.plen": "",
	"V.ipf.intr.med.partcp.m.sg.dat.praet": "",
	"V.ipf.intr.med.partcp.m.sg.dat.praet.plen": "",
	"V.ipf.intr.med.partcp.m.sg.gen.praes": "",
	"V.ipf.intr.med.partcp.m.sg.gen.praes.plen": "",
	"V.ipf.intr.med.partcp.m.sg.gen.praet": "",
	"V.ipf.intr.med.partcp.m.sg.gen.praet.plen": "",
	"V.ipf.intr.med.partcp.m.sg.ins.praes": "",
	"V.ipf.intr.med.partcp.m.sg.ins.praes.plen": "",
	"V.ipf.intr.med.partcp.m.sg.ins.praet.plen": "",
	"V.ipf.intr.med.partcp.m.sg.loc.praes.plen": "",
	"V.ipf.intr.med.partcp.m.sg.loc.praet": "",
	"V.ipf.intr.med.partcp.m.sg.loc.praet.plen": "",
	"V.ipf.intr.med.partcp.m.sg.nom.praes": "",
	"V.ipf.intr.med.partcp.m.sg.nom.praes.plen": "",
	"V.ipf.intr.med.partcp.m.sg.nom.praet.plen": "",
	"V.ipf.intr.med.partcp.n.sg.acc.praes": "",
	"V.ipf.intr.med.partcp.n.sg.acc.praes.plen": "",
	"V.ipf.intr.med.partcp.n.sg.acc.praet.plen": "",
	"V.ipf.intr.med.partcp.n.sg.dat.praes.plen": "",
	"V.ipf.intr.med.partcp.n.sg.gen.praes.plen": "",
	"V.ipf.intr.med.partcp.n.sg.gen.praet.plen": "",
	"V.ipf.intr.med.partcp.n.sg.ins.praes.plen": "",
	"V.ipf.intr.med.partcp.n.sg.loc.praes": "",
	"V.ipf.intr.med.partcp.n.sg.loc.praes.plen": "",
	"V.ipf.intr.med.partcp.n.sg.loc.praet.plen": "",
	"V.ipf.intr.med.partcp.n.sg.nom.praes.plen": "",
	"V.ipf.intr.med.partcp.n.sg.nom.praet.plen": "",
	"V.ipf.intr.med.partcp.pl.acc.praes": "",
	"V.ipf.intr.med.partcp.pl.acc.praes.plen": "",
	"V.ipf.intr.med.partcp.pl.acc.praet.plen": "",
	"V.ipf.intr.med.partcp.pl.dat.praes.plen": "",
	"V.ipf.intr.med.partcp.pl.dat.praet.plen": "",
	"V.ipf.intr.med.partcp.pl.gen.praes": "",
	"V.ipf.intr.med.partcp.pl.gen.praes.plen": "",
	"V.ipf.intr.med.partcp.pl.gen.praet": "",
	"V.ipf.intr.med.partcp.pl.gen.praet.plen": "",
	"V.ipf.intr.med.partcp.pl.ins.praes": "",
	"V.ipf.intr.med.partcp.pl.ins.praes.plen": "",
	"V.ipf.intr.med.partcp.pl.ins.praet.plen": "",
	"V.ipf.intr.med.partcp.pl.loc.praes.plen": "",
	"V.ipf.intr.med.partcp.pl.loc.praet.plen": "",
	"V.ipf.intr.med.partcp.pl.nom.praes": "",
	"V.ipf.intr.med.partcp.pl.nom.praes.plen": "",
	"V.ipf.intr.med.partcp.pl.nom.praet.plen": "",
	"V.ipf.intr.med.partcp.praes.n.sg.gen.plen": "",
	"V.ipf.intr.med.pl.2p.imper": "",
	"V.ipf.intr.med.pl.praes.1p.indic": "",
	"V.ipf.intr.med.pl.praes.2p.indic": "",
	"V.ipf.intr.med.pl.praes.3p.indic": "",
	"V.ipf.intr.med.pl.praes.3p.indic.anom": "",
	"V.ipf.intr.med.pl.praet.indic": "",
	"V.ipf.intr.med.praes.3p.sg.indic": "",
	"V.ipf.intr.med.praes.sg.3p.indic": "",
	"V.ipf.intr.med.sg.2p.imper": "",
	"V.ipf.intr.med.sg.2p.imper.anom": "",
	"V.ipf.intr.med.sg.3p.praes.indic": "",
	"V.ipf.intr.med.sg.n.praet.indic": "",
	"V.ipf.intr.med.sg.praes.1p.indic": "",
	"V.ipf.intr.med.sg.praes.2p.indic": "",
	"V.ipf.intr.med.sg.praes.3p.indic": "",
	"V.ipf.intr.med.sg.praes.3p.indic.abbr": "",
	"V.ipf.intr.med.sg.praes.3p.indic.anom": "",
	"V.ipf.intr.med.sg.praes.3p.indic.distort": "",
	"V.ipf.intr.m.sg.act.praet.indic": "",
	"V.ipf.intr.n.sg.act.praet.indic": "",
	"V.ipf.intr.partcp.act.praes.f.sg.acc.plen": "",
	"V.ipf.intr.partcp.act.praes.f.sg.nom.plen": "",
	"V.ipf.intr.partcp.act.praes.inan.m.sg.acc.plen": "",
	"V.ipf.intr.partcp.act.praes.pl.ins.plen": "",
	"V.ipf.intr.partcp.act.praes.pl.loc.plen": "",
	"V.ipf.intr.partcp.f.sg.nom.act.praes.plen": "",
	"V.ipf.intr.partcp.m.sg.dat.med.praes.plen": "",
	"V.ipf.intr.partcp.m.sg.gen.act.praes.plen": "",
	"V.ipf.intr.partcp.m.sg.nom.act.praes.plen": "",
	"V.ipf.intr.partcp.m.sg.nom.med.praes.plen": "",
	"V.ipf.intr.partcp.n.sg.ins.act.praes": "",
	"V.ipf.intr.partcp.pl.dat.med.praes.plen": "",
	"V.ipf.intr.partcp.pl.gen.act.praes.plen": "",
	"V.ipf.intr.partcp.pl.gen.med.praes.plen": "",
	"V.ipf.intr.partcp.pl.ins.act.praes.plen": "",
	"V.ipf.intr.partcp.pl.nom.act.praes.plen": "",
	"V.ipf.intr.partcp.pl.nom.med.praes.plen": "",
	"V.ipf.intr.partcp.praes.pass.f.sg.gen.plen": "",
	"V.ipf.intr.partcp.praes.pass.f.sg.ins.plen": "",
	"V.ipf.intr.partcp.praes.pass.f.sg.nom.plen": "",
	"V.ipf.intr.partcp.praes.pass.m.sg.acc.plen": "",
	"V.ipf.intr.partcp.praes.pass.m.sg.dat.plen": "",
	"V.ipf.intr.partcp.praes.pass.m.sg.gen.plen": "",
	"V.ipf.intr.partcp.praes.pass.m.sg.loc.plen": "",
	"V.ipf.intr.partcp.praes.pass.n.sg.acc.plen": "",
	"V.ipf.intr.pl.act.praes.2p.indic": "",
	"V.ipf.intr.pl.act.praes.3p.indic": "",
	"V.ipf.intr.pl.act.praet.indic": "",
	"V.ipf.intr.praes.sg.3p.indic.act": "",
	"V.ipf.intr.sg.act.praes.3p.indic": "",
	"V.ipf.intr.sg.act.praes.3p.indic.anom": "",
	"V.ipf.intr.sg.praes.3p.indic.abbr": "",
	"V.ipf.intr.sg.praes.3p.indic.act": "",
	"V.ipf.med.f.sg.intr.praet.indic": "",
	"V.ipf.med.inf.intr": "",
	"V.ipf.med.n.sg.intr.praet.indic": "",
	"V.ipf.med.pl.intr.praes.3p.indic": "",
	"V.ipf.med.pl.intr.praet.indic": "",
	"V.ipf.med.praes.sg.1p.indic": "",
	"V.ipf.med.praes.sg.2p.indic": "",
	"V.ipf.med.praes.sg.3p.indic": "",
	"V.ipf.med.praet.pl.indic.anom": "",
	"V.ipf.med.praet.sg.n.indic": "",
	"V.ipf.med.sg.intr.praes.3p.indic": "",
	"V.ipf.m.sg.tran.act.praet.indic": "",
	"V.ipf.partcp.m.sg.gen.intr.act.praes.plen": "",
	"V.ipf.partcp.praes.pass.sg.n.nom": "",
	"V.ipf.partcp.praes.pl.acc.inan.act": "",
	"V.ipf.partcp.praes.pl.ins.act": "",
	"V.ipf.partcp.praes.pl.nom.act": "",
	"V.ipf.partcp.praes.sg.f.gen.act": "",
	"V.ipf.partcp.praes.sg.f.loc.act": "",
	"V.ipf.partcp.praes.sg.f.nom.act": "",
	"V.ipf.partcp.praes.sg.m.gen.act": "",
	"V.ipf.partcp.praes.sg.m.ins.act": "",
	"V.ipf.partcp.praes.sg.n.dat.act": "",
	"V.ipf.partcp.praet.pl.acc.inan.act": "",
	"V.ipf.partcp.praet.sg.f.loc.act": "",
	"V.ipf.partcp.praet.sg.m.nom.act": "",
	"V.ipf.pl.tran.act.praes.3p.indic": "",
	"V.ipf.praes.pl.1p.act.indic": "",
	"V.ipf.praes.sg.1p.act.indic": "",
	"V.ipf.praes.sg.1p.indic.distort": "",
	"V.ipf.praes.sg.2p.act.indic": "",
	"V.ipf.praes.sg.3p.act.indic": "",
	"V.ipf.praes.sg.3p.indic.distort": "",
	"V.ipf.praet.pl.act.indic": "",
	"V.ipf.praet.sg.f.act.indic": "",
	"V.ipf.praet.sg.m.act.indic": "",
	"V.ipf.sg.tran.act.praes.3p.indic": "",
	"V.ipf.tran.act.2p.imper.sg.abbr": "",
	"V.ipf.tran.act.f.sg.praet.indic": "",
	"V.ipf.tran.act.ger.praes": "",
	"V.ipf.tran.act.ger.praes.anom": "",
	"V.ipf.tran.act.imper.2p.abbr": "",
	"V.ipf.tran.act.imper.2p.sg": "",
	"V.ipf.tran.act.imper.2p.sg.abbr": "",
	"V.ipf.tran.act.imper.sg.2p.abbr": "",
	"V.ipf.tran.act.imper.sg.abbr": "",
	"V.ipf.tran.act.indic.praes.3p.sg": "",
	"V.ipf.tran.act.inf": "",
	"V.ipf.tran.act.m.sg.praet.indic": "",
	"V.ipf.tran.act.n.sg.praet.indic": "",
	"V.ipf.tran.act.partcp.f.sg.acc.praes.plen": "",
	"V.ipf.tran.act.partcp.f.sg.gen.praes.plen": "",
	"V.ipf.tran.act.partcp.f.sg.ins.praes.plen": "",
	"V.ipf.tran.act.partcp.f.sg.loc.praes": "",
	"V.ipf.tran.act.partcp.f.sg.loc.praes.plen": "",
	"V.ipf.tran.act.partcp.f.sg.nom.praes.plen": "",
	"V.ipf.tran.act.partcp.f.sg.nom.praet.plen": "",
	"V.ipf.tran.act.partcp.m.sg.acc.praes": "",
	"V.ipf.tran.act.partcp.m.sg.acc.praes.plen": "",
	"V.ipf.tran.act.partcp.m.sg.gen.praes.plen": "",
	"V.ipf.tran.act.partcp.m.sg.gen.praet.plen": "",
	"V.ipf.tran.act.partcp.m.sg.ins.praes": "",
	"V.ipf.tran.act.partcp.m.sg.ins.praes.plen": "",
	"V.ipf.tran.act.partcp.m.sg.loc.praes.plen": "",
	"V.ipf.tran.act.partcp.m.sg.nom.praes.plen": "",
	"V.ipf.tran.act.partcp.m.sg.nom.praet.plen": "",
	"V.ipf.tran.act.partcp.n.sg.dat.praes.plen": "",
	"V.ipf.tran.act.partcp.n.sg.dat.praet.plen": "",
	"V.ipf.tran.act.partcp.n.sg.gen.praes.plen": "",
	"V.ipf.tran.act.partcp.n.sg.ins.praes.plen": "",
	"V.ipf.tran.act.partcp.n.sg.nom.praes.plen": "",
	"V.ipf.tran.act.partcp.pl.acc.praes.plen": "",
	"V.ipf.tran.act.partcp.pl.dat.praes": "",
	"V.ipf.tran.act.partcp.pl.dat.praes.plen": "",
	"V.ipf.tran.act.partcp.pl.gen.praes": "",
	"V.ipf.tran.act.partcp.pl.gen.praes.plen": "",
	"V.ipf.tran.act.partcp.pl.gen.praet.plen": "",
	"V.ipf.tran.act.partcp.pl.ins.praes.plen": "",
	"V.ipf.tran.act.partcp.pl.loc.praes.plen": "",
	"V.ipf.tran.act.partcp.pl.nom.praes.plen": "",
	"V.ipf.tran.act.partcp.pl.nom.praet": "",
	"V.ipf.tran.act.partcp.pl.nom.praet.plen": "",
	"V.ipf.tran.act.partcp.praes.f.sg.gen.plen": "",
	"V.ipf.tran.act.pl.2p.imper": "",
	"V.ipf.tran.act.pl.2p.imper.abbr": "",
	"V.ipf.tran.act.pl.praes.1p.indic": "",
	"V.ipf.tran.act.pl.praes.2p.indic": "",
	"V.ipf.tran.act.pl.praes.3p.indic": "",
	"V.ipf.tran.act.pl.praet.indic": "",
	"V.ipf.tran.act.praes.1p.sg.distort": "",
	"V.ipf.tran.act.praes.1p.sg.indic.distort": "",
	"V.ipf.tran.act.praes.3p.indic": "",
	"V.ipf.tran.act.praes.3p.pl.indic": "",
	"V.ipf.tran.act.praes.3p.sg.indic": "",
	"V.ipf.tran.act.praes.sg.3p.indic": "",
	"V.ipf.tran.act.praet.f.sg.indic": "",
	"V.ipf.tran.act.praet.m.sg.indic": "",
	"V.ipf.tran.act.sg.2p.imper": "",
	"V.ipf.tran.act.sg.2p.imper.abbr": "",
	"V.ipf.tran.act.sg.praes.1p.indic": "",
	"V.ipf.tran.act.sg.praes.2p.indic": "",
	"V.ipf.tran.act.sg.praes.3p.indic": "",
	"V.ipf.tran.act.sg.praes.3p.indic.anom": "",
	"V.ipf.tran.act.sg.praes.3p.indic.distort": "",
	"V.ipf.tran.f.sg.act.praet.indic": "",
	"V.ipf.tran.f.sg.praet.act.indic": "",
	"V.ipf.tran.ger.act.praes": "",
	"V.ipf.tran.ger.act.praes.anom": "",
	"V.ipf.tran.ger.act.praet.anom": "",
	"V.ipf.tran.ger.praes.act.anom": "",
	"V.ipf.tran.imper.2p.sg.act.abbr": "",
	"V.ipf.tran.imper.sg.2p.act.abbr": "",
	"V.ipf.tran.imper.sg.2p.act.distort": "",
	"V.ipf.tran.imper.sg.act.abbr": "",
	"V.ipf.tran.inf": "",
	"V.ipf.tran.inf.act": "",
	"V.ipf.tran.m.sg.act.praet.indic": "",
	"V.ipf.tran.n.sg.act.praet.indic": "",
	"V.ipf.tran.partcp.act.m.sg.nom.praes.plen": "",
	"V.ipf.tran.partcp.act.pl.gen.plen": "",
	"V.ipf.tran.partcp.act.pl.nom.praes.plen": "",
	"V.ipf.tran.partcp.act.praes.pl.nom.plen": "",
	"V.ipf.tran.partcp.f.sg.acc.act.praes": "",
	"V.ipf.tran.partcp.f.sg.acc.act.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.acc.act.praet": "",
	"V.ipf.tran.partcp.f.sg.acc.act.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.acc.pass.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.acc.pass.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.brev.pass.praes": "",
	"V.ipf.tran.partcp.f.sg.brev.pass.praet": "",
	"V.ipf.tran.partcp.f.sg.dat.act.praes": "",
	"V.ipf.tran.partcp.f.sg.dat.act.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.dat.act.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.dat.pass.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.dat.pass.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.gen.act.praes": "",
	"V.ipf.tran.partcp.f.sg.gen.act.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.gen.act.praet": "",
	"V.ipf.tran.partcp.f.sg.gen.act.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.gen.pass.praes": "",
	"V.ipf.tran.partcp.f.sg.gen.pass.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.gen.pass.praes.plen.abbr": "",
	"V.ipf.tran.partcp.f.sg.gen.pass.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.ins.act.praes": "",
	"V.ipf.tran.partcp.f.sg.ins.act.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.ins.act.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.ins.pass.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.ins.pass.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.loc.act.praes": "",
	"V.ipf.tran.partcp.f.sg.loc.act.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.loc.act.praet": "",
	"V.ipf.tran.partcp.f.sg.loc.act.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.loc.pass.praes": "",
	"V.ipf.tran.partcp.f.sg.loc.pass.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.loc.pass.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.nom.act.praes": "",
	"V.ipf.tran.partcp.f.sg.nom.act.praes.abbr": "",
	"V.ipf.tran.partcp.f.sg.nom.act.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.nom.act.praet": "",
	"V.ipf.tran.partcp.f.sg.nom.act.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.nom.pass.praes.plen": "",
	"V.ipf.tran.partcp.f.sg.nom.pass.praes.plen.abbr": "",
	"V.ipf.tran.partcp.f.sg.nom.pass.praet.plen": "",
	"V.ipf.tran.partcp.f.sg.pass.praet.brev": "",
	"V.ipf.tran.partcp.m.pl.gen.act.praes.abbr": "",
	"V.ipf.tran.partcp.m.sg.acc.act.praes": "",
	"V.ipf.tran.partcp.m.sg.acc.act.praes.abbr": "",
	"V.ipf.tran.partcp.m.sg.acc.act.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.acc.act.praet": "",
	"V.ipf.tran.partcp.m.sg.acc.act.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.acc.pass.praes": "",
	"V.ipf.tran.partcp.m.sg.acc.pass.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.acc.pass.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.brev.pass.praes": "",
	"V.ipf.tran.partcp.m.sg.brev.pass.praet": "",
	"V.ipf.tran.partcp.m.sg.dat.act.praes": "",
	"V.ipf.tran.partcp.m.sg.dat.act.praes.abbr": "",
	"V.ipf.tran.partcp.m.sg.dat.act.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.dat.act.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.dat.pass.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.dat.pass.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.gen.act.praes": "",
	"V.ipf.tran.partcp.m.sg.gen.act.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.gen.act.praet": "",
	"V.ipf.tran.partcp.m.sg.gen.act.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.gen.pass.praes": "",
	"V.ipf.tran.partcp.m.sg.gen.pass.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.gen.pass.praes.plen.abbr": "",
	"V.ipf.tran.partcp.m.sg.gen.pass.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.ins.act.praes": "",
	"V.ipf.tran.partcp.m.sg.ins.act.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.ins.act.praet": "",
	"V.ipf.tran.partcp.m.sg.ins.act.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.ins.pass.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.ins.pass.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.loc.act.praes": "",
	"V.ipf.tran.partcp.m.sg.loc.act.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.loc.act.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.loc.pass.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.loc.pass.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.nom.act.praes": "",
	"V.ipf.tran.partcp.m.sg.nom.act.praes.abbr": "",
	"V.ipf.tran.partcp.m.sg.nom.act.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.nom.act.praet": "",
	"V.ipf.tran.partcp.m.sg.nom.act.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.nom.pass.praes": "",
	"V.ipf.tran.partcp.m.sg.nom.pass.praes.plen": "",
	"V.ipf.tran.partcp.m.sg.nom.pass.praet": "",
	"V.ipf.tran.partcp.m.sg.nom.pass.praet.plen": "",
	"V.ipf.tran.partcp.m.sg.pass.praet.brev": "",
	"V.ipf.tran.partcp.n.sg.acc.act.praes": "",
	"V.ipf.tran.partcp.n.sg.acc.act.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.acc.act.praet": "",
	"V.ipf.tran.partcp.n.sg.acc.act.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.acc.pass.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.acc.pass.praet": "",
	"V.ipf.tran.partcp.n.sg.acc.pass.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.brev.pass.praes": "",
	"V.ipf.tran.partcp.n.sg.brev.pass.praet": "",
	"V.ipf.tran.partcp.n.sg.brev.pass.praet.anom": "",
	"V.ipf.tran.partcp.n.sg.dat.act.praes": "",
	"V.ipf.tran.partcp.n.sg.dat.act.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.dat.pass.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.gen.act.praes": "",
	"V.ipf.tran.partcp.n.sg.gen.act.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.gen.act.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.gen.pass.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.gen.pass.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.ins.act.praes": "",
	"V.ipf.tran.partcp.n.sg.ins.act.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.ins.act.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.ins.pass.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.ins.pass.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.loc.act.praes": "",
	"V.ipf.tran.partcp.n.sg.loc.act.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.loc.pass.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.loc.pass.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.nom.act.praes": "",
	"V.ipf.tran.partcp.n.sg.nom.act.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.nom.act.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.nom.pass.praes.plen": "",
	"V.ipf.tran.partcp.n.sg.nom.pass.praes.plen.anom": "",
	"V.ipf.tran.partcp.n.sg.nom.pass.praet.plen": "",
	"V.ipf.tran.partcp.n.sg.pass.praet.brev": "",
	"V.ipf.tran.partcp.pass.praes.f.sg.gen": "",
	"V.ipf.tran.partcp.pass.praes.pl.gen.abbr": "",
	"V.ipf.tran.partcp.pass.praes.pl.nom.plen": "",
	"V.ipf.tran.partcp.pass.praet.brev.m.sg": "",
	"V.ipf.tran.partcp.pl.acc.act.praes": "",
	"V.ipf.tran.partcp.pl.acc.act.praes.plen": "",
	"V.ipf.tran.partcp.pl.acc.act.praet": "",
	"V.ipf.tran.partcp.pl.acc.act.praet.plen": "",
	"V.ipf.tran.partcp.pl.acc.pass.praes": "",
	"V.ipf.tran.partcp.pl.acc.pass.praes.plen": "",
	"V.ipf.tran.partcp.pl.acc.pass.praet": "",
	"V.ipf.tran.partcp.pl.acc.pass.praet.plen": "",
	"V.ipf.tran.partcp.pl.brev.pass.praes": "",
	"V.ipf.tran.partcp.pl.brev.pass.praet": "",
	"V.ipf.tran.partcp.pl.dat.act.praes": "",
	"V.ipf.tran.partcp.pl.dat.act.praes.plen": "",
	"V.ipf.tran.partcp.pl.dat.act.praet.plen": "",
	"V.ipf.tran.partcp.pl.dat.pass.praes": "",
	"V.ipf.tran.partcp.pl.dat.pass.praes.plen": "",
	"V.ipf.tran.partcp.pl.dat.pass.praet.plen": "",
	"V.ipf.tran.partcp.pl.gen.act.praes": "",
	"V.ipf.tran.partcp.pl.gen.act.praes.plen": "",
	"V.ipf.tran.partcp.pl.gen.act.praet.plen": "",
	"V.ipf.tran.partcp.pl.gen.pass.praes.plen": "",
	"V.ipf.tran.partcp.pl.gen.pass.praet.plen": "",
	"V.ipf.tran.partcp.pl.ins.act.praes": "",
	"V.ipf.tran.partcp.pl.ins.act.praes.plen": "",
	"V.ipf.tran.partcp.pl.ins.act.praet": "",
	"V.ipf.tran.partcp.pl.ins.act.praet.plen": "",
	"V.ipf.tran.partcp.pl.ins.pass.praes": "",
	"V.ipf.tran.partcp.pl.ins.pass.praes.plen": "",
	"V.ipf.tran.partcp.pl.ins.pass.praet": "",
	"V.ipf.tran.partcp.pl.ins.pass.praet.plen": "",
	"V.ipf.tran.partcp.pl.loc.act.praes": "",
	"V.ipf.tran.partcp.pl.loc.act.praes.plen": "",
	"V.ipf.tran.partcp.pl.loc.act.praet.plen": "",
	"V.ipf.tran.partcp.pl.loc.pass.praes.plen": "",
	"V.ipf.tran.partcp.pl.loc.pass.praet.plen": "",
	"V.ipf.tran.partcp.pl.nom.act.praes": "",
	"V.ipf.tran.partcp.pl.nom.act.praes.plen": "",
	"V.ipf.tran.partcp.pl.nom.act.praet": "",
	"V.ipf.tran.partcp.pl.nom.act.praet.plen": "",
	"V.ipf.tran.partcp.pl.nom.pass.praes": "",
	"V.ipf.tran.partcp.pl.nom.pass.praes.plen": "",
	"V.ipf.tran.partcp.pl.nom.pass.praet": "",
	"V.ipf.tran.partcp.pl.nom.pass.praet.plen": "",
	"V.ipf.tran.partcp.pl.pass.praet.brev": "",
	"V.ipf.tran.partcp.praes.act.m.sg.nom": "",
	"V.ipf.tran.partcp.praes.act.m.sg.nom.plen": "",
	"V.ipf.tran.partcp.praes.act.pl.gen": "",
	"V.ipf.tran.partcp.praes.act.pl.gen.plen": "",
	"V.ipf.tran.partcp.praes.act.sg.loc.plen": "",
	"V.ipf.tran.partcp.praes.act.sg.nom.plen": "",
	"V.ipf.tran.partcp.sg.n.brev.pass.praet": "",
	"V.ipf.tran.pl.2p.act.imper": "",
	"V.ipf.tran.pl.act.1p.imper": "",
	"V.ipf.tran.pl.act.2p.imper": "",
	"V.ipf.tran.pl.act.fut.3p.indic": "",
	"V.ipf.tran.pl.act.praes.1p.indic": "",
	"V.ipf.tran.pl.act.praes.1p.indic.anom": "",
	"V.ipf.tran.pl.act.praes.2p.indic": "",
	"V.ipf.tran.pl.act.praes.2p.indic.distort": "",
	"V.ipf.tran.pl.act.praes.3p.indic": "",
	"V.ipf.tran.pl.act.praes.3p.indic.anom": "",
	"V.ipf.tran.pl.act.praes.3p.indic.distort": "",
	"V.ipf.tran.pl.act.praet.indic": "",
	"V.ipf.tran.pl.praes.1p.indic": "",
	"V.ipf.tran.praes.ger.act": "",
	"V.ipf.tran.praet.act.m.sg.indic": "",
	"V.ipf.tran.sg.act.1p.praes.indic": "",
	"V.ipf.tran.sg.act.2p.imper": "",
	"V.ipf.tran.sg.act.2p.imper.abbr": "",
	"V.ipf.tran.sg.act.praes.1p.indic": "",
	"V.ipf.tran.sg.act.praes.1p.indic.distort": "",
	"V.ipf.tran.sg.act.praes.2p.indic": "",
	"V.ipf.tran.sg.act.praes.3p.indic": "",
	"V.ipf.tran.sg.act.praes.3p.indic.anom": "",
	"V.ipf.tran.sg.praes.act.3p.indic": "",
	"V.med.ipf.ger.praes": "",
	"V.med.ipf.imper.sg.2p": "",
	"V.med.ipf.inf": "",
	"V.med.ipf.intr.praes.3p.sg.abbr": "",
	"V.med.ipf.praes.sg.1p.indic": "",
	"V.med.ipf.praes.sg.3p.indic": "",
	"V.med.ipf.praet.pl.indic": "",
	"V.med.ipf.praet.sg.f.indic": "",
	"V.med.ipf.praet.sg.n.indic": "",
	"V.med.pf.fut.pl.1p.indic": "",
	"V.med.pf.fut.pl.2p.indic": "",
	"V.med.pf.fut.pl.3p.indic": "",
	"V.med.pf.fut.sg.1p.indic": "",
	"V.med.pf.fut.sg.2p.indic": "",
	"V.med.pf.fut.sg.3p.indic": "",
	"V.med.pf.ger.praet": "",
	"V.med.pf.imper.pl.2p": "",
	"V.med.pf.imper.sg.2p": "",
	"V.med.pf.inf": "",
	"V.med.pf.partcp.praet.pl.loc": "",
	"V.med.pf.partcp.praet.pl.nom": "",
	"V.med.pf.partcp.praet.sg.f.acc": "",
	"V.med.pf.partcp.praet.sg.f.gen": "",
	"V.med.pf.partcp.praet.sg.f.ins": "",
	"V.med.pf.partcp.praet.sg.m.acc.inan": "",
	"V.med.pf.partcp.praet.sg.m.dat": "",
	"V.med.pf.partcp.praet.sg.m.gen": "",
	"V.med.pf.partcp.praet.sg.m.ins": "",
	"V.med.pf.partcp.praet.sg.n.ins": "",
	"V.med.pf.praet.n.sg.indic": "",
	"V.med.pf.praet.pl.indic": "",
	"V.med.pf.praet.sg.f.indic": "",
	"V.med.pf.praet.sg.m.indic": "",
	"V.med.pf.praet.sg.n.indic": "",
	"V.med.praet.pl.ipf.indic": "",
	"V.pf.act.praet.indic": "",
	"V.pf.fut.pl.1p.act.indic": "",
	"V.pf.fut.pl.1p.indic": "",
	"V.pf.fut.pl.2p.act.indic": "",
	"V.pf.fut.pl.3p.act.indic": "",
	"V.pf.fut.sg.1p.act.indic": "",
	"V.pf.fut.sg.2p.act.indic": "",
	"V.pf.fut.sg.3p.act.indic": "",
	"V.pf.fut.sg.3p.indic": "",
	"V.pf.fut.sg.3p.indic.distort": "",
	"V.pf.ger.praet": "",
	"V.pf.ger.praet.act": "",
	"V.pf.imper.pl.2p.act": "",
	"V.pf.imper.sg.2p.act": "",
	"V.pf.imper.sg.2p.act.anom": "",
	"V.pf.inf": "",
	"V.pf.inf.act": "",
	"V.pf.inf.act.distort": "",
	"V.pf.intr.act.f.sg.praet.indic": "",
	"V.pf.intr.act.fut.3p.sg.indic": "",
	"V.pf.intr.act.fut.sg.1p.indic": "",
	"V.pf.intr.act.ger.praet": "",
	"V.pf.intr.act.imper.2p.sg": "",
	"V.pf.intr.act.imper.sg.1p": "",
	"V.pf.intr.act.imper.sg.2p.anom": "",
	"V.pf.intr.act.inf": "",
	"V.pf.intr.act.inf.anom": "",
	"V.pf.intr.act.inf.distort": "",
	"V.pf.intr.act.m.sg.praet.distort.indic": "",
	"V.pf.intr.act.m.sg.praet.indic": "",
	"V.pf.intr.act.m.sg.praet.indic.abbr": "",
	"V.pf.intr.act.m.sg.praet.indic.anom": "",
	"V.pf.intr.act.n.sg.praet.indic": "",
	"V.pf.intr.act.n.sg.praet.indic.distort": "",
	"V.pf.intr.act.partcp.f.sg.acc.praet": "",
	"V.pf.intr.act.partcp.f.sg.acc.praet.plen": "",
	"V.pf.intr.act.partcp.f.sg.dat.praet.plen": "",
	"V.pf.intr.act.partcp.f.sg.gen.praet": "",
	"V.pf.intr.act.partcp.f.sg.gen.praet.plen": "",
	"V.pf.intr.act.partcp.f.sg.ins.praet": "",
	"V.pf.intr.act.partcp.f.sg.ins.praet.plen": "",
	"V.pf.intr.act.partcp.f.sg.loc.praet.plen": "",
	"V.pf.intr.act.partcp.f.sg.nom.praet": "",
	"V.pf.intr.act.partcp.f.sg.nom.praet.plen": "",
	"V.pf.intr.act.partcp.m.sg.acc.praet": "",
	"V.pf.intr.act.partcp.m.sg.acc.praet.plen": "",
	"V.pf.intr.act.partcp.m.sg.dat.praet": "",
	"V.pf.intr.act.partcp.m.sg.dat.praet.plen": "",
	"V.pf.intr.act.partcp.m.sg.gen.praet": "",
	"V.pf.intr.act.partcp.m.sg.gen.praet.plen": "",
	"V.pf.intr.act.partcp.m.sg.ins.praet": "",
	"V.pf.intr.act.partcp.m.sg.ins.praet.plen": "",
	"V.pf.intr.act.partcp.m.sg.loc.praet": "",
	"V.pf.intr.act.partcp.m.sg.loc.praet.plen": "",
	"V.pf.intr.act.partcp.m.sg.nom.praet": "",
	"V.pf.intr.act.partcp.m.sg.nom.praet.plen": "",
	"V.pf.intr.act.partcp.n.sg.acc.praet": "",
	"V.pf.intr.act.partcp.n.sg.acc.praet.plen": "",
	"V.pf.intr.act.partcp.n.sg.dat.praet": "",
	"V.pf.intr.act.partcp.n.sg.dat.praet.plen": "",
	"V.pf.intr.act.partcp.n.sg.gen.praet": "",
	"V.pf.intr.act.partcp.n.sg.gen.praet.plen": "",
	"V.pf.intr.act.partcp.n.sg.ins.praet": "",
	"V.pf.intr.act.partcp.n.sg.ins.praet.plen": "",
	"V.pf.intr.act.partcp.n.sg.loc.praet.plen": "",
	"V.pf.intr.act.partcp.n.sg.nom.praet": "",
	"V.pf.intr.act.partcp.n.sg.nom.praet.plen": "",
	"V.pf.intr.act.partcp.pl.acc.praet": "",
	"V.pf.intr.act.partcp.pl.acc.praet.plen": "",
	"V.pf.intr.act.partcp.pl.dat.praet": "",
	"V.pf.intr.act.partcp.pl.dat.praet.plen": "",
	"V.pf.intr.act.partcp.pl.gen.praet": "",
	"V.pf.intr.act.partcp.pl.gen.praet.plen": "",
	"V.pf.intr.act.partcp.pl.ins.praet": "",
	"V.pf.intr.act.partcp.pl.ins.praet.plen": "",
	"V.pf.intr.act.partcp.pl.loc.praet": "",
	"V.pf.intr.act.partcp.pl.loc.praet.plen": "",
	"V.pf.intr.act.partcp.pl.nom.praet": "",
	"V.pf.intr.act.partcp.pl.nom.praet.plen": "",
	"V.pf.intr.act.pl.1p.imper": "",
	"V.pf.intr.act.pl.2p.imper": "",
	"V.pf.intr.act.pl.2p.imper.anom": "",
	"V.pf.intr.act.pl.fut.1p.indic": "",
	"V.pf.intr.act.pl.fut.2p.indic": "",
	"V.pf.intr.act.pl.fut.3p.indic": "",
	"V.pf.intr.act.pl.praet.anom.indic": "",
	"V.pf.intr.act.pl.praet.indic": "",
	"V.pf.intr.act.pl.praet.indic.distort": "",
	"V.pf.intr.act.praet.pl.indic": "",
	"V.pf.intr.act.praet.pl.indic.distort": "",
	"V.pf.intr.act.praet.sg.anom.indic": "",
	"V.pf.intr.act.sg.2p.imper": "",
	"V.pf.intr.act.sg.fut.1p.indic": "",
	"V.pf.intr.act.sg.fut.2p.indic": "",
	"V.pf.intr.act.sg.fut.3p.indic": "",
	"V.pf.intr.f.sg.act.praet.indic": "",
	"V.pf.intr.f.sg.praet.indic": "",
	"V.pf.intr.med.f.praet.indic": "",
	"V.pf.intr.med.f.sg.praet.indic": "",
	"V.pf.intr.med.f.sg.praet.indic.abbr": "",
	"V.pf.intr.med.f.sg.praet.indic.anom": "",
	"V.pf.intr.med.ger.praet": "",
	"V.pf.intr.med.ger.praet.anom": "",
	"V.pf.intr.med.inf": "",
	"V.pf.intr.med.m.sg.praet.indic": "",
	"V.pf.intr.med.n.sg.praet.indic": "",
	"V.pf.intr.med.obsc.m.sg.praet.indic.distort": "",
	"V.pf.intr.med.partcp.f.sg.acc.praet": "",
	"V.pf.intr.med.partcp.f.sg.acc.praet.plen": "",
	"V.pf.intr.med.partcp.f.sg.dat.praet.plen": "",
	"V.pf.intr.med.partcp.f.sg.gen.praet": "",
	"V.pf.intr.med.partcp.f.sg.gen.praet.plen": "",
	"V.pf.intr.med.partcp.f.sg.ins.praet.plen": "",
	"V.pf.intr.med.partcp.f.sg.loc.praet": "",
	"V.pf.intr.med.partcp.f.sg.loc.praet.plen": "",
	"V.pf.intr.med.partcp.f.sg.nom.praet": "",
	"V.pf.intr.med.partcp.f.sg.nom.praet.plen": "",
	"V.pf.intr.med.partcp.m.sg.acc.praet": "",
	"V.pf.intr.med.partcp.m.sg.acc.praet.plen": "",
	"V.pf.intr.med.partcp.m.sg.dat.praet": "",
	"V.pf.intr.med.partcp.m.sg.dat.praet.plen": "",
	"V.pf.intr.med.partcp.m.sg.gen.praet": "",
	"V.pf.intr.med.partcp.m.sg.gen.praet.plen": "",
	"V.pf.intr.med.partcp.m.sg.ins.praet": "",
	"V.pf.intr.med.partcp.m.sg.ins.praet.plen": "",
	"V.pf.intr.med.partcp.m.sg.loc.praet": "",
	"V.pf.intr.med.partcp.m.sg.loc.praet.plen": "",
	"V.pf.intr.med.partcp.m.sg.nom.praet": "",
	"V.pf.intr.med.partcp.m.sg.nom.praet.plen": "",
	"V.pf.intr.med.partcp.n.sg.acc.praet.plen": "",
	"V.pf.intr.med.partcp.n.sg.dat.praet.plen": "",
	"V.pf.intr.med.partcp.n.sg.gen.praet": "",
	"V.pf.intr.med.partcp.n.sg.gen.praet.plen": "",
	"V.pf.intr.med.partcp.n.sg.ins.praet.plen": "",
	"V.pf.intr.med.partcp.n.sg.loc.praet.plen": "",
	"V.pf.intr.med.partcp.n.sg.nom.praet.plen": "",
	"V.pf.intr.med.partcp.pl.acc.praet": "",
	"V.pf.intr.med.partcp.pl.acc.praet.plen": "",
	"V.pf.intr.med.partcp.pl.dat.praet": "",
	"V.pf.intr.med.partcp.pl.dat.praet.plen": "",
	"V.pf.intr.med.partcp.pl.gen.praet.plen": "",
	"V.pf.intr.med.partcp.pl.ins.praet.plen": "",
	"V.pf.intr.med.partcp.pl.loc.praet": "",
	"V.pf.intr.med.partcp.pl.loc.praet.plen": "",
	"V.pf.intr.med.partcp.pl.nom.praet": "",
	"V.pf.intr.med.partcp.pl.nom.praet.plen": "",
	"V.pf.intr.med.pl.1p.imper": "",
	"V.pf.intr.med.pl.2p.imper": "",
	"V.pf.intr.med.pl.fut.1p.indic": "",
	"V.pf.intr.med.pl.fut.2p.indic": "",
	"V.pf.intr.med.pl.fut.3p.indic": "",
	"V.pf.intr.med.pl.praet.indic": "",
	"V.pf.intr.med.sg.1p.imper": "",
	"V.pf.intr.med.sg.2p.imper": "",
	"V.pf.intr.med.sg.fut.1p.indic": "",
	"V.pf.intr.med.sg.fut.2p.indic": "",
	"V.pf.intr.med.sg.fut.3p.indic": "",
	"V.pf.intr.partcp.act.praet.f.sg.ins.plen": "",
	"V.pf.intr.partcp.act.praet.pl.gen.plen": "",
	"V.pf.intr.partcp.act.praet.pl.nom.plen": "",
	"V.pf.intr.partcp.f.sg.loc.act.praet.plen": "",
	"V.pf.intr.partcp.f.sg.nom.act.praet": "",
	"V.pf.intr.partcp.m.sg.brev.pass.praet": "",
	"V.pf.intr.partcp.m.sg.gen.med.praet.plen": "",
	"V.pf.intr.partcp.m.sg.loc.med.praet.plen": "",
	"V.pf.intr.partcp.m.sg.nom.act.praet.plen": "",
	"V.pf.intr.partcp.pass.praet.brev.f.sg": "",
	"V.pf.intr.partcp.pass.praet.brev.m.sg": "",
	"V.pf.intr.partcp.pass.praet.brev.n.sg": "",
	"V.pf.intr.partcp.pass.praet.brev.pl": "",
	"V.pf.intr.partcp.praet.pass.m.sg.loc.plen": "",
	"V.pf.intr.partcp.praet.pass.m.sg.nom.plen": "",
	"V.pf.intr.partcp.praet.pass.n.sg.brev": "",
	"V.pf.intr.partcp.praet.pass.n.sg.loc.plen": "",
	"V.pf.intr.partcp.praet.pass.pl.acc.plen": "",
	"V.pf.intr.pl.act.praet.indic": "",
	"V.pf.intr.pl.med.fut.1p.indic": "",
	"V.pf.intr.sg.3p.fut.indic.act": "",
	"V.pf.intr.sg.act.fut.2p.indic": "",
	"V.pf.med.fut.pl.1p.indic": "",
	"V.pf.med.ger.praet": "",
	"V.pf.med.inf": "",
	"V.pf.med.intr.praet.sg.nom.indic.abbr": "",
	"V.pf.med.praet.pl.indic": "",
	"V.pf.med.praet.sg.n.indic": "",
	"V.pf.partcp.praet.pass.brev.pl": "",
	"V.pf.partcp.praet.pass.brev.sg.f": "",
	"V.pf.partcp.praet.pass.brev.sg.m": "",
	"V.pf.partcp.praet.pass.brev.sg.n": "",
	"V.pf.partcp.praet.pass.pl.acc.anim": "",
	"V.pf.partcp.praet.pass.pl.acc.inan": "",
	"V.pf.partcp.praet.pass.pl.gen": "",
	"V.pf.partcp.praet.pass.pl.ins": "",
	"V.pf.partcp.praet.pass.pl.loc": "",
	"V.pf.partcp.praet.pass.pl.nom": "",
	"V.pf.partcp.praet.pass.sg.f.acc": "",
	"V.pf.partcp.praet.pass.sg.f.dat": "",
	"V.pf.partcp.praet.pass.sg.f.gen": "",
	"V.pf.partcp.praet.pass.sg.f.ins": "",
	"V.pf.partcp.praet.pass.sg.f.loc": "",
	"V.pf.partcp.praet.pass.sg.f.nom": "",
	"V.pf.partcp.praet.pass.sg.m.acc.anim": "",
	"V.pf.partcp.praet.pass.sg.m.acc.inan": "",
	"V.pf.partcp.praet.pass.sg.m.dat": "",
	"V.pf.partcp.praet.pass.sg.m.gen": "",
	"V.pf.partcp.praet.pass.sg.m.ins": "",
	"V.pf.partcp.praet.pass.sg.m.loc": "",
	"V.pf.partcp.praet.pass.sg.m.nom": "",
	"V.pf.partcp.praet.pass.sg.m.nom.distort": "",
	"V.pf.partcp.praet.pass.sg.n.acc": "",
	"V.pf.partcp.praet.pass.sg.n.gen": "",
	"V.pf.partcp.praet.pass.sg.n.ins": "",
	"V.pf.partcp.praet.pass.sg.n.loc": "",
	"V.pf.partcp.praet.pass.sg.n.nom": "",
	"V.pf.partcp.praet.pl.acc.anim.act": "",
	"V.pf.partcp.praet.pl.acc.inan.act": "",
	"V.pf.partcp.praet.pl.gen.act": "",
	"V.pf.partcp.praet.pl.ins.act": "",
	"V.pf.partcp.praet.pl.nom.act": "",
	"V.pf.partcp.praet.sg.f.acc.act": "",
	"V.pf.partcp.praet.sg.f.gen.act": "",
	"V.pf.partcp.praet.sg.f.ins.act": "",
	"V.pf.partcp.praet.sg.f.nom.act": "",
	"V.pf.partcp.praet.sg.m.acc.anim.act": "",
	"V.pf.partcp.praet.sg.m.acc.inan.act": "",
	"V.pf.partcp.praet.sg.m.gen.act": "",
	"V.pf.partcp.praet.sg.m.nom.act": "",
	"V.pf.partcp.praet.sg.n.acc.act": "",
	"V.pf.partcp.praet.sg.n.nom.act": "",
	"V.pf.praet.pl.act.indic": "",
	"V.pf.praet.pl.indic": "",
	"V.pf.praet.sg.f.act.indic": "",
	"V.pf.praet.sg.f.indic": "",
	"V.pf.praet.sg.m.act.indic": "",
	"V.pf.praet.sg.m.indic": "",
	"V.pf.praet.sg.n.act.indic": "",
	"V.pf.praet.sg.n.indic": "",
	"V.pf.tran.act.f.sg.praet.indic": "",
	"V.pf.tran.act.ger.praet": "",
	"V.pf.tran.act.imper.2p.sg": "",
	"V.pf.tran.act.imper.2p.sg.abbr": "",
	"V.pf.tran.act.imper.2p.sg.anom": "",
	"V.pf.tran.act.imper.pl.2p.anom": "",
	"V.pf.tran.act.imper.sg.2p.abbr": "",
	"V.pf.tran.act.imper.sg.2p.distort": "",
	"V.pf.tran.act.inf": "",
	"V.pf.tran.act.m.sg.praet.indic": "",
	"V.pf.tran.act.m.sg.praet.indic.distort": "",
	"V.pf.tran.act.n.sg.praet.indic": "",
	"V.pf.tran.act.partcp.f.sg.acc.praet.plen": "",
	"V.pf.tran.act.partcp.f.sg.gen.praet.plen": "",
	"V.pf.tran.act.partcp.f.sg.ins.praet": "",
	"V.pf.tran.act.partcp.f.sg.nom.praet": "",
	"V.pf.tran.act.partcp.m.sg.acc.praet": "",
	"V.pf.tran.act.partcp.m.sg.nom.praet.plen": "",
	"V.pf.tran.act.partcp.n.sg.acc.praet": "",
	"V.pf.tran.act.partcp.pl.acc.praet.plen": "",
	"V.pf.tran.act.partcp.pl.dat.praet.plen": "",
	"V.pf.tran.act.partcp.pl.gen.praet": "",
	"V.pf.tran.act.partcp.pl.gen.praet.plen": "",
	"V.pf.tran.act.partcp.pl.ins.praet.plen": "",
	"V.pf.tran.act.partcp.pl.loc.praet.plen": "",
	"V.pf.tran.act.partcp.pl.nom.praet.plen": "",
	"V.pf.tran.act.pl.1p.imper": "",
	"V.pf.tran.act.pl.2p.imper": "",
	"V.pf.tran.act.pl.fut.1p.indic": "",
	"V.pf.tran.act.pl.fut.3p.indic": "",
	"V.pf.tran.act.pl.praet.indic": "",
	"V.pf.tran.act.praet.f.sg.indic": "",
	"V.pf.tran.act.praet.m.sg.indic": "",
	"V.pf.tran.act.sg.2p.imper": "",
	"V.pf.tran.act.sg.fut.1p.indic": "",
	"V.pf.tran.act.sg.fut.2p.indic": "",
	"V.pf.tran.act.sg.fut.3p.indic": "",
	"V.pf.tran.f.sg.act.praet.indic": "",
	"V.pf.tran.f.sg.act.praet.indic.distort": "",
	"V.pf.tran.ger.act.praet": "",
	"V.pf.tran.ger.act.praet.anom": "",
	"V.pf.tran.indic.praet.sg.m": "",
	"V.pf.tran.inf.act": "",
	"V.pf.tran.inf.act.distort": "",
	"V.pf.tran.m.sg.act.praet.anom.indic": "",
	"V.pf.tran.m.sg.act.praet.indic": "",
	"V.pf.tran.n.sg.act.praet.indic": "",
	"V.pf.tran.obsc.act.inf.abbr": "",
	"V.pf.tran.partcp.brev.m.sg.pass.praet": "",
	"V.pf.tran.partcp.f.sg.acc.act.praet": "",
	"V.pf.tran.partcp.f.sg.acc.act.praet.plen": "",
	"V.pf.tran.partcp.f.sg.acc.pass.praet": "",
	"V.pf.tran.partcp.f.sg.acc.pass.praet.plen": "",
	"V.pf.tran.partcp.f.sg.brev.pass.praet": "",
	"V.pf.tran.partcp.f.sg.dat.act.praet.plen": "",
	"V.pf.tran.partcp.f.sg.dat.pass.praet": "",
	"V.pf.tran.partcp.f.sg.dat.pass.praet.plen": "",
	"V.pf.tran.partcp.f.sg.gen.act.praet": "",
	"V.pf.tran.partcp.f.sg.gen.act.praet.plen": "",
	"V.pf.tran.partcp.f.sg.gen.pass.praet": "",
	"V.pf.tran.partcp.f.sg.gen.pass.praet.plen": "",
	"V.pf.tran.partcp.f.sg.ins.act.praet": "",
	"V.pf.tran.partcp.f.sg.ins.act.praet.plen": "",
	"V.pf.tran.partcp.f.sg.ins.pass.praet": "",
	"V.pf.tran.partcp.f.sg.ins.pass.praet.plen": "",
	"V.pf.tran.partcp.f.sg.loc.act.praet.plen": "",
	"V.pf.tran.partcp.f.sg.loc.pass.praet": "",
	"V.pf.tran.partcp.f.sg.loc.pass.praet.plen": "",
	"V.pf.tran.partcp.f.sg.nom.act.praet": "",
	"V.pf.tran.partcp.f.sg.nom.act.praet.plen": "",
	"V.pf.tran.partcp.f.sg.nom.pass.praet": "",
	"V.pf.tran.partcp.f.sg.nom.pass.praet.plen": "",
	"V.pf.tran.partcp.f.sg.nom.pass.praet.plen.anom": "",
	"V.pf.tran.partcp.f.sg.pass.praet.brev": "",
	"V.pf.tran.partcp.m.sg.acc.act.praet": "",
	"V.pf.tran.partcp.m.sg.acc.act.praet.plen": "",
	"V.pf.tran.partcp.m.sg.acc.pass.praet": "",
	"V.pf.tran.partcp.m.sg.acc.pass.praet.plen": "",
	"V.pf.tran.partcp.m.sg.brev.pass.praet": "",
	"V.pf.tran.partcp.m.sg.dat.act.praet.plen": "",
	"V.pf.tran.partcp.m.sg.dat.pass.praet": "",
	"V.pf.tran.partcp.m.sg.dat.pass.praet.plen": "",
	"V.pf.tran.partcp.m.sg.gen.act.praet": "",
	"V.pf.tran.partcp.m.sg.gen.act.praet.plen": "",
	"V.pf.tran.partcp.m.sg.gen.pass.praet": "",
	"V.pf.tran.partcp.m.sg.gen.pass.praet.plen": "",
	"V.pf.tran.partcp.m.sg.ins.act.praet.plen": "",
	"V.pf.tran.partcp.m.sg.ins.pass.praet": "",
	"V.pf.tran.partcp.m.sg.ins.pass.praet.plen": "",
	"V.pf.tran.partcp.m.sg.loc.act.praet.plen": "",
	"V.pf.tran.partcp.m.sg.loc.pass.praet": "",
	"V.pf.tran.partcp.m.sg.loc.pass.praet.plen": "",
	"V.pf.tran.partcp.m.sg.nom.act.praet": "",
	"V.pf.tran.partcp.m.sg.nom.act.praet.plen": "",
	"V.pf.tran.partcp.m.sg.nom.pass.praet": "",
	"V.pf.tran.partcp.m.sg.nom.pass.praet.plen": "",
	"V.pf.tran.partcp.m.sg.pass.praet.brev": "",
	"V.pf.tran.partcp.n.brev.pass.praet": "",
	"V.pf.tran.partcp.n.sg.acc.act.praet.plen": "",
	"V.pf.tran.partcp.n.sg.acc.pass.praet": "",
	"V.pf.tran.partcp.n.sg.acc.pass.praet.plen": "",
	"V.pf.tran.partcp.n.sg.brev.pass.praet": "",
	"V.pf.tran.partcp.n.sg.dat.act.praet.plen": "",
	"V.pf.tran.partcp.n.sg.dat.pass.praet.plen": "",
	"V.pf.tran.partcp.n.sg.gen.act.praet.plen": "",
	"V.pf.tran.partcp.n.sg.gen.pass.praet": "",
	"V.pf.tran.partcp.n.sg.gen.pass.praet.plen": "",
	"V.pf.tran.partcp.n.sg.ins.act.praet.plen": "",
	"V.pf.tran.partcp.n.sg.ins.pass.praet": "",
	"V.pf.tran.partcp.n.sg.ins.pass.praet.plen": "",
	"V.pf.tran.partcp.n.sg.loc.pass.praet": "",
	"V.pf.tran.partcp.n.sg.loc.pass.praet.plen": "",
	"V.pf.tran.partcp.n.sg.nom.act.praet.plen": "",
	"V.pf.tran.partcp.n.sg.nom.pass.praet": "",
	"V.pf.tran.partcp.n.sg.nom.pass.praet.plen": "",
	"V.pf.tran.partcp.n.sg.nom.pass.praet.plen.abbr": "",
	"V.pf.tran.partcp.n.sg.pass.praet.brev": "",
	"V.pf.tran.partcp.pass.praet.brev.m.sg": "",
	"V.pf.tran.partcp.pass.praet.brev.pl": "",
	"V.pf.tran.partcp.pass.praet.brev.sg.m": "",
	"V.pf.tran.partcp.pass.praet.f.sg.acc.plen": "",
	"V.pf.tran.partcp.pass.praet.f.sg.nom.plen": "",
	"V.pf.tran.partcp.pass.praet.m.sg.acc": "",
	"V.pf.tran.partcp.pass.praet.n.sg.brev": "",
	"V.pf.tran.partcp.pass.praet.pl.gen.plen": "",
	"V.pf.tran.partcp.pass.praet.sg.n.nom.plen.abbr": "",
	"V.pf.tran.partcp.pl.acc.act.praet": "",
	"V.pf.tran.partcp.pl.acc.act.praet.plen": "",
	"V.pf.tran.partcp.pl.acc.pass.praet": "",
	"V.pf.tran.partcp.pl.acc.pass.praet.plen": "",
	"V.pf.tran.partcp.pl.brev.pass.praet": "",
	"V.pf.tran.partcp.pl.dat.act.praet.plen": "",
	"V.pf.tran.partcp.pl.dat.pass.praet": "",
	"V.pf.tran.partcp.pl.dat.pass.praet.plen": "",
	"V.pf.tran.partcp.pl.gen.act.praet": "",
	"V.pf.tran.partcp.pl.gen.act.praet.plen": "",
	"V.pf.tran.partcp.pl.gen.pass.praet": "",
	"V.pf.tran.partcp.pl.gen.pass.praet.plen": "",
	"V.pf.tran.partcp.pl.ins.act.praet.plen": "",
	"V.pf.tran.partcp.pl.ins.pass.praet": "",
	"V.pf.tran.partcp.pl.ins.pass.praet.plen": "",
	"V.pf.tran.partcp.pl.loc.act.praet.plen": "",
	"V.pf.tran.partcp.pl.loc.pass.praet": "",
	"V.pf.tran.partcp.pl.loc.pass.praet.plen": "",
	"V.pf.tran.partcp.pl.nom.act.praet": "",
	"V.pf.tran.partcp.pl.nom.act.praet.plen": "",
	"V.pf.tran.partcp.pl.nom.pass.praet": "",
	"V.pf.tran.partcp.pl.nom.pass.praet.plen": "",
	"V.pf.tran.partcp.pl.pass.praet.brev": "",
	"V.pf.tran.partcp.praet.pass.m.sg.brev": "",
	"V.pf.tran.partcp.praet.pass.pl.ins": "",
	"V.pf.tran.pass.partcp.praet.pl.acc.plen": "",
	"V.pf.tran.pass.partcp.praet.pl.loc.plen": "",
	"V.pf.tran.pl.act.1p.imper": "",
	"V.pf.tran.pl.act.2p.imper": "",
	"V.pf.tran.pl.act.fut.1p.indic": "",
	"V.pf.tran.pl.act.fut.2p.indic": "",
	"V.pf.tran.pl.act.fut.3p.indic": "",
	"V.pf.tran.pl.act.praet.indic": "",
	"V.pf.tran.pl.act.praet.indic.anom": "",
	"V.pf.tran.pl.act.praet.indic.distort": "",
	"V.pf.tran.pl.praet.indic": "",
	"V.pf.tran.sg.act.1p.imper": "",
	"V.pf.tran.sg.act.2p.imper": "",
	"V.pf.tran.sg.act.2p.imper.abbr": "",
	"V.pf.tran.sg.act.2p.imper.anom": "",
	"V.pf.tran.sg.act.fut.1p.indic": "",
	"V.pf.tran.sg.act.fut.1p.indic.anom": "",
	"V.pf.tran.sg.act.fut.2p.indic": "",
	"V.pf.tran.sg.act.fut.2p.indic.distort": "",
	"V.pf.tran.sg.act.fut.3p.anom.indic": "",
	"V.pf.tran.sg.act.fut.3p.indic": "",
	"V.pf.tran.sg.act.fut.3p.indic.anom": "",
	"V.pf.tran.sg.praet.n.indic": "",
	"V.praes.ger.ipf.act": "",
	"V.tran.ipf.act.imper.2p.sg.abbr": "",
	"V.tran.ipf.act.sg.1p.praes.indic": "",
	"V.tran.ipf.ger.praes.act": "",
	"V.tran.ipf.imper.pl.2p.act": "",
	"V.tran.ipf.imper.sg.2p.act": "",
	"V.tran.ipf.inf.act": "",
	"V.tran.ipf.partcp.praes.pass.pl.nom": "",
	"V.tran.ipf.partcp.praes.pass.sg.f.acc": "",
	"V.tran.ipf.partcp.praes.pass.sg.f.gen": "",
	"V.tran.ipf.partcp.praes.pass.sg.f.ins": "",
	"V.tran.ipf.partcp.praes.pass.sg.f.nom": "",
	"V.tran.ipf.partcp.praes.pass.sg.m.gen": "",
	"V.tran.ipf.partcp.praes.pass.sg.m.loc": "",
	"V.tran.ipf.partcp.praes.pass.sg.m.nom": "",
	"V.tran.ipf.partcp.praes.pass.sg.n.loc": "",
	"V.tran.ipf.partcp.praes.pl.acc.anim.act": "",
	"V.tran.ipf.partcp.praes.pl.acc.inan.act": "",
	"V.tran.ipf.partcp.praes.pl.gen.act": "",
	"V.tran.ipf.partcp.praes.pl.ins.act": "",
	"V.tran.ipf.partcp.praes.pl.loc.act": "",
	"V.tran.ipf.partcp.praes.pl.nom.act": "",
	"V.tran.ipf.partcp.praes.sg.f.acc.act": "",
	"V.tran.ipf.partcp.praes.sg.f.gen.act": "",
	"V.tran.ipf.partcp.praes.sg.f.ins.act": "",
	"V.tran.ipf.partcp.praes.sg.f.loc.act": "",
	"V.tran.ipf.partcp.praes.sg.f.nom.act": "",
	"V.tran.ipf.partcp.praes.sg.m.acc.inan.act": "",
	"V.tran.ipf.partcp.praes.sg.m.dat.act": "",
	"V.tran.ipf.partcp.praes.sg.m.gen.act": "",
	"V.tran.ipf.partcp.praes.sg.m.ins.act": "",
	"V.tran.ipf.partcp.praes.sg.m.loc.act": "",
	"V.tran.ipf.partcp.praes.sg.m.nom.act": "",
	"V.tran.ipf.partcp.praes.sg.n.gen.act": "",
	"V.tran.ipf.partcp.praes.sg.n.nom.act": "",
	"V.tran.ipf.partcp.praet.pass.brev.sg.m": "",
	"V.tran.ipf.partcp.praet.pass.brev.sg.n": "",
	"V.tran.ipf.partcp.praet.pass.pl.acc.inan": "",
	"V.tran.ipf.partcp.praet.pass.pl.nom": "",
	"V.tran.ipf.partcp.praet.pass.sg.f.acc": "",
	"V.tran.ipf.partcp.praet.pass.sg.f.loc": "",
	"V.tran.ipf.partcp.praet.pass.sg.n.ins": "",
	"V.tran.ipf.partcp.praet.pl.acc.inan.act": "",
	"V.tran.ipf.partcp.praet.pl.dat.act": "",
	"V.tran.ipf.partcp.praet.pl.loc.act": "",
	"V.tran.ipf.partcp.praet.pl.nom.act": "",
	"V.tran.ipf.partcp.praet.sg.f.nom.act": "",
	"V.tran.ipf.partcp.praet.sg.m.acc.inan.act": "",
	"V.tran.ipf.partcp.praet.sg.m.ins.act": "",
	"V.tran.ipf.partcp.praet.sg.m.loc.act": "",
	"V.tran.ipf.partcp.praet.sg.n.dat.act": "",
	"V.tran.ipf.praes.pl.1p.act.indic": "",
	"V.tran.ipf.praes.pl.2p.act.indic": "",
	"V.tran.ipf.praes.pl.3p.act.indic": "",
	"V.tran.ipf.praes.sg.1p.act.indic": "",
	"V.tran.ipf.praes.sg.2p.act.indic": "",
	"V.tran.ipf.praes.sg.3p.act.indic": "",
	"V.tran.ipf.praet.pl.act.indic": "",
	"V.tran.ipf.praet.sg.f.act.indic": "",
	"V.tran.ipf.praet.sg.m.act.indic": "",
	"V.tran.ipf.praet.sg.n.act.indic": "",
	"V.tran.partcp.f.sg.brev.pass.praet.pf": "",
	"V.tran.partcp.f.sg.loc.pf.pass.praet.plen": "",
	"V.tran.partcp.f.sg.nom.pf.pass.praet.plen": "",
	"V.tran.partcp.m.sg.brev.pass.praet.pf": "",
	"V.tran.partcp.m.sg.gen.pf.pass.praet.plen": "",
	"V.tran.partcp.n.sg.gen.pf.pass.praet.plen": "",
	"V.tran.partcp.pl.brev.pass.praet.pf": "",
	"V.tran.partcp.pl.gen.pf.pass.praet.plen": "",
	"V.tran.partcp.pl.nom.pf.pass.praet.plen": "",
	"V.tran.pf.fut.pl.1p.act.indic": "",
	"V.tran.pf.fut.pl.2p.act.indic": "",
	"V.tran.pf.fut.pl.3p.act.indic": "",
	"V.tran.pf.fut.sg.1p.act.indic": "",
	"V.tran.pf.fut.sg.2p.act.indic": "",
	"V.tran.pf.fut.sg.3p.act.indic": "",
	"V.tran.pf.ger.praet.act": "",
	"V.tran.pf.imper.pl.2p.act": "",
	"V.tran.pf.imper.sg.2p.act": "",
	"V.tran.pf.inf.act": "",
	"V.tran.pf.partcp.praet.pass.brev.pl": "",
	"V.tran.pf.partcp.praet.pass.brev.sg.f": "",
	"V.tran.pf.partcp.praet.pass.brev.sg.m": "",
	"V.tran.pf.partcp.praet.pass.brev.sg.n": "",
	"V.tran.pf.partcp.praet.pass.pl.gen": "",
	"V.tran.pf.partcp.praet.pass.pl.nom": "",
	"V.tran.pf.partcp.praet.pass.sg.f.acc": "",
	"V.tran.pf.partcp.praet.pass.sg.f.nom": "",
	"V.tran.pf.partcp.praet.pass.sg.m.acc.inan": "",
	"V.tran.pf.partcp.praet.pass.sg.m.ins": "",
	"V.tran.pf.partcp.praet.pass.sg.m.nom": "",
	"V.tran.pf.partcp.praet.pass.sg.n.acc": "",
	"V.tran.pf.partcp.praet.pass.sg.n.gen": "",
	"V.tran.pf.partcp.praet.pass.sg.n.ins": "",
	"V.tran.pf.partcp.praet.pass.sg.n.loc": "",
	"V.tran.pf.partcp.praet.sg.m.acc.anim.act": "",
	"V.tran.pf.praet.pl.act.indic": "",
	"V.tran.pf.praet.sg.f.act.indic": "",
	"V.tran.pf.praet.sg.m.act.indic": "",
	"V.tran.pf.praet.sg.n.act.indic": "",
	"V.tran.praes.sg.3p.ipf.act.indic": "",
	"V.tran.praet.pl.ipf.act.indic": "",
}

if __name__ == '__main__':
	allTags = set([])
	for big in bigDict:
		for tag in big.split('.'):
			allTags.add(tag)
	
	print("tags left: " + str(allTags - set(weeDict)))
